/******************************************************************************
* Project Name		: CyCube3
* Description       : Reading the touch pads and provide via I2C-slave
* Components        : CapSense, I2C
* File Name			: main.c
* Version 			: 1.0
* Device Used		: CY8C4025AXI-S412
* Software Used		: PSoC Creator 4.4
* Related Hardware	: CyCube3 v1.0 
* Auithor           : Holger Wech
* Documentation     : https://www.hackster.io/projects/bac785
********************************************************************************
* No Copyright :-)
********************************************************************************/
#include "project.h"

// +++ globals +++
uint16_t u16TouchFlag; // Bit[8:0] reflect the related touch field, e.g. bit 4 is set to 1 when the center pad of the cube is touched

int main(void)
{
    CyGlobalIntEnable; /* Enable global interrupts. */

    // EZi2C
    
    EZI2C_Start();
    EZI2C_EzI2CSetBuffer1(sizeof(CapSense_dsRam), sizeof(CapSense_dsRam), (uint8 *)&CapSense_dsRam);
    EZI2C_EzI2CSetBuffer2(sizeof(u16TouchFlag), sizeof(u16TouchFlag), (uint8 *)&u16TouchFlag);
        
    // CapSense
    
    CapSense_Start();           // Initialize Component
    CapSense_ScanAllWidgets();  // Scan all widgets
    
    u16TouchFlag = 1;
    
    for(;;)
    {
        // CapSense / Touch
        
        if(CapSense_NOT_BUSY == CapSense_IsBusy())
        {  
            CapSense_ProcessAllWidgets(); // Process all widgets
            
            #ifdef CY_SCB_EZI2C_Tuner_H
                CapSense_RunTuner();
            #endif
            
            if (CapSense_IsWidgetActive (CapSense_T1_WDGT_ID) ) { u16TouchFlag = u16TouchFlag | 0x0001; } else { u16TouchFlag = u16TouchFlag & (~0x0001); }
            if (CapSense_IsWidgetActive (CapSense_T2_WDGT_ID) ) { u16TouchFlag = u16TouchFlag | 0x0002; } else { u16TouchFlag = u16TouchFlag & (~0x0002); }
            if (CapSense_IsWidgetActive (CapSense_T3_WDGT_ID) ) { u16TouchFlag = u16TouchFlag | 0x0004; } else { u16TouchFlag = u16TouchFlag & (~0x0004); }            
            if (CapSense_IsWidgetActive (CapSense_T4_WDGT_ID) ) { u16TouchFlag = u16TouchFlag | 0x0008; } else { u16TouchFlag = u16TouchFlag & (~0x0008); }
            if (CapSense_IsWidgetActive (CapSense_T5_WDGT_ID) ) { u16TouchFlag = u16TouchFlag | 0x0010; } else { u16TouchFlag = u16TouchFlag & (~0x0010); }
            if (CapSense_IsWidgetActive (CapSense_T6_WDGT_ID) ) { u16TouchFlag = u16TouchFlag | 0x0020; } else { u16TouchFlag = u16TouchFlag & (~0x0020); }
            if (CapSense_IsWidgetActive (CapSense_T7_WDGT_ID) ) { u16TouchFlag = u16TouchFlag | 0x0040; } else { u16TouchFlag = u16TouchFlag & (~0x0040); }
            if (CapSense_IsWidgetActive (CapSense_T8_WDGT_ID) ) { u16TouchFlag = u16TouchFlag | 0x0080; } else { u16TouchFlag = u16TouchFlag & (~0x0080); }
            if (CapSense_IsWidgetActive (CapSense_T9_WDGT_ID) ) { u16TouchFlag = u16TouchFlag | 0x0100; } else { u16TouchFlag = u16TouchFlag & (~0x0100); }
            
           CapSense_ScanAllWidgets(); // Start next scan
            
        } // if(CapSense_NOT_BUSY ...
    } // for(;;)
} // main()

/* [] END OF FILE */

