/******************************************************************************
* Project Name		: CyCube3
* Description       : Main unit: LED Control, I2C-Master/Reading touch status from other pages
* Components        : CapSense, I2C-Master
* File Name			: main.c
* Version 			: 0.2
* Device Used		: CY8C4025AXI-S412
* Software Used		: PSoC Creator 4.3
* Related Hardware	: CyCube3 v1.0 
* Author    		: Holger Wech
* Documentation     : https://www.hackster.io/projects/bac785
********************************************************************************
* No Copyright :-)
********************************************************************************/
#include "project.h"
#include "cydisabledsheets.h"
#include "stdlib.h"
#include "cube_touch.h"

#define SoftwareUART__DISABLED

#define P0
#define P1
#define P2
#define P3
#define P4
#define P5

#ifndef SoftwareUART__DISABLED
    #include <stdio.h>  // e.g.: sprintf()
    char acPrintfBuffer[64];
    volatile uint16_t u32aCubeTouchOld[6];
    volatile uint32_t u32UntouchCnt;
#endif

#define TOUCHTIME (16u)
#define ROTATETIME (4u)
#define LED_INTENSITY (3u) // max=1, min=10
volatile uint32_t u32LedIntensity, u32LedIntensity_temp;
volatile uint32_t u32CubeOffFlag;

#define CUBE_OFF (0)

typedef enum enCubeMode_t 
{
    CUBEMODE_MIX,
    CUBEMODE_MIX_WAIT_FOR_TOUCH, 
    CUBEMODE_MIX_DONE,
    
    CUBEMODE_LIGHT,
    CUBEMODE_LIGHT_WAIT_FOR_TOUCH, 
    CUBEMODE_LIGHT_DONE,
    
    CUBEMODE_RUN,
    
    CUBEMODE_OFF,
    CUBEMODE_OFF_LEDON,
    CUBEMODE_OFF_DONE,
    
} enCubeMode_t;

volatile enCubeMode_t enCubeMode, enCubeModeKeep;

typedef enum enCubeMove_t 
{
    CUBEMOVE_01_00 = 0,
    CUBEMOVE_00_01,
    CUBEMOVE_04_05,
    CUBEMOVE_05_04,
    CUBEMOVE_07_06,
    CUBEMOVE_06_07,
    CUBEMOVE_05_00,
    CUBEMOVE_00_05,
    CUBEMOVE_04_01,
    CUBEMOVE_01_04,
    CUBEMOVE_03_02,
    CUBEMOVE_02_03,
    CUBEMOVE_10_11,
    CUBEMOVE_11_10,
    CUBEMOVE_13_12,
    CUBEMOVE_12_13,
    CUBEMOVE_16_17,
    CUBEMOVE_17_16
} enCubeMove_t;

volatile enCubeMove_t enCubeMove;
volatile uint32_t u32CubeMoveSteps;

volatile uint32_t u32TouchedCenterField;    // keep the first touched center field 


volatile uint32_t u32temp;

// +++ globals +++
volatile uint32_t u32Timer25ms_Delay;
volatile uint32_t u32Timer25ms_DelayCenter;

volatile uint32_t u32Timer25ms_Delay00;
volatile uint32_t u32Timer25ms_Delay01;
volatile uint32_t u32Timer25ms_Delay02;
volatile uint32_t u32Timer25ms_Delay03;
volatile uint32_t u32Timer25ms_Delay05;
volatile uint32_t u32Timer25ms_Delay06;
volatile uint32_t u32Timer25ms_Delay07;
volatile uint32_t u32Timer25ms_Delay08;

volatile uint32_t u32Timer25ms_Delay09;
volatile uint32_t u32Timer25ms_Delay10;
volatile uint32_t u32Timer25ms_Delay11;
volatile uint32_t u32Timer25ms_Delay12;
volatile uint32_t u32Timer25ms_Delay14;
volatile uint32_t u32Timer25ms_Delay15;
volatile uint32_t u32Timer25ms_Delay16;
volatile uint32_t u32Timer25ms_Delay17;

volatile uint32_t u32Timer25ms_Delay18;
volatile uint32_t u32Timer25ms_Delay19;
volatile uint32_t u32Timer25ms_Delay20;
volatile uint32_t u32Timer25ms_Delay21;
volatile uint32_t u32Timer25ms_Delay23;
volatile uint32_t u32Timer25ms_Delay24;
volatile uint32_t u32Timer25ms_Delay25;
volatile uint32_t u32Timer25ms_Delay26;

volatile uint32_t u32Timer25ms_Delay27;
volatile uint32_t u32Timer25ms_Delay28;
volatile uint32_t u32Timer25ms_Delay29;
volatile uint32_t u32Timer25ms_Delay30;
volatile uint32_t u32Timer25ms_Delay32;
volatile uint32_t u32Timer25ms_Delay33;
volatile uint32_t u32Timer25ms_Delay34;
volatile uint32_t u32Timer25ms_Delay35;

volatile uint32_t u32Timer25ms_Delay36;
volatile uint32_t u32Timer25ms_Delay37;
volatile uint32_t u32Timer25ms_Delay38;
volatile uint32_t u32Timer25ms_Delay39;
volatile uint32_t u32Timer25ms_Delay41;
volatile uint32_t u32Timer25ms_Delay42;
volatile uint32_t u32Timer25ms_Delay43;
volatile uint32_t u32Timer25ms_Delay44;

volatile uint32_t u32Timer25ms_Delay45;
volatile uint32_t u32Timer25ms_Delay46;
volatile uint32_t u32Timer25ms_Delay47;
volatile uint32_t u32Timer25ms_Delay48;
volatile uint32_t u32Timer25ms_Delay50;
volatile uint32_t u32Timer25ms_Delay51;
volatile uint32_t u32Timer25ms_Delay52;
volatile uint32_t u32Timer25ms_Delay53;


volatile uint32_t u32Timer25ms_DelayTurn;


volatile uint16_t u32aCubeTouch[6]; // Bit[8:0] reflect the related touch field, e.g. bit 4 is set to 1 when the center pad of the cube is touched
volatile uint16_t u32TouchFlag;     // temporary CubeTouch value

volatile uint32_t u32Touch_2;        // set to 1, if at least one first touch is detected

volatile uint32_t u32TouchClickCount;

volatile enTouchStateCenter_t enTouchStateCenter;

volatile enTouchState_t enTouchState00;
volatile enTouchState_t enTouchState01;
volatile enTouchState_t enTouchState02;
volatile enTouchState_t enTouchState03;
volatile enTouchState_t enTouchState05;
volatile enTouchState_t enTouchState06;
volatile enTouchState_t enTouchState07;
volatile enTouchState_t enTouchState08;

volatile enTouchState_t enTouchState09;
volatile enTouchState_t enTouchState10;
volatile enTouchState_t enTouchState11;
volatile enTouchState_t enTouchState12;
volatile enTouchState_t enTouchState14;
volatile enTouchState_t enTouchState15;
volatile enTouchState_t enTouchState16;
volatile enTouchState_t enTouchState17;

volatile enTouchState_t enTouchState18;
volatile enTouchState_t enTouchState19;
volatile enTouchState_t enTouchState20;
volatile enTouchState_t enTouchState21;
volatile enTouchState_t enTouchState23;
volatile enTouchState_t enTouchState24;
volatile enTouchState_t enTouchState25;
volatile enTouchState_t enTouchState26;

volatile enTouchState_t enTouchState27;
volatile enTouchState_t enTouchState28;
volatile enTouchState_t enTouchState29;
volatile enTouchState_t enTouchState30;
volatile enTouchState_t enTouchState32;
volatile enTouchState_t enTouchState33;
volatile enTouchState_t enTouchState34;
volatile enTouchState_t enTouchState35;

volatile enTouchState_t enTouchState36;
volatile enTouchState_t enTouchState37;
volatile enTouchState_t enTouchState38;
volatile enTouchState_t enTouchState39;
volatile enTouchState_t enTouchState41;
volatile enTouchState_t enTouchState42;
volatile enTouchState_t enTouchState43;
volatile enTouchState_t enTouchState44;

volatile enTouchState_t enTouchState45;
volatile enTouchState_t enTouchState46;
volatile enTouchState_t enTouchState47;
volatile enTouchState_t enTouchState48;
volatile enTouchState_t enTouchState50;
volatile enTouchState_t enTouchState51;
volatile enTouchState_t enTouchState52;
volatile enTouchState_t enTouchState53;


#ifndef StripLights__DISABLED
/* ---------------------------------------------------------------------------- 
 * StripLights by SCB
 * ----------------------------------------------------------------------------
 * Blocking code, 3.75us per Pixel
 * e.g.: 
 *   10 Pixel =  37 us
 *  100 Pixel = 370 us
 * 1000 Pixel = 3.7 ms
 * ----------------------------------------------------------------------------
 */

#define WS2812_CNT (54)
#define DELAY (1500)

#define WS2812_ZERO (4)
#define WS2812_ONE  (6)

uint8_t u8WS2812_BUFFER[WS2812_CNT * 9]; 

uint32_t WS2812_byte2binary(uint8_t u8Byte)
{
    uint8_t u8i;
    uint32_t u32result;
    
    // '0' -> 100
    // '1' -> 110
    
    u32result = 0;

    // Prozess 7 upper bits
    for (u8i=0; u8i<7; u8i++)
    {
        if  (u8Byte & 0x80)
        {
            u32result =  u32result + WS2812_ONE; // '1'
        }
        else
        {
            u32result =  u32result + WS2812_ZERO; // '0'
        }
        
        u32result = u32result << 3; // next WS2812 bit   
        u8Byte = u8Byte << 1; // source byte -> bit shift left
        
    } // for (u8i ...)
    
    // LSB without final shift
    if  (u8Byte & 0x80)
    {
        u32result =  u32result + WS2812_ONE; // '1'
    }
    else
    {
        u32result =  u32result + WS2812_ZERO; // '0'
    }
    
    return(u32result);
}

// u32Color - - b b r r g g 
void  StripLights_MemClear(uint32_t u32Color)
{
    uint16_t u16cnt;
    uint8_t *pu8buffer;
    uint32_t u32R, u32G, u32B;
    uint8_t u8Rhigh, u8Rmid, u8Rlow; // high-, mid-, low-nibble
    uint8_t u8Ghigh, u8Gmid, u8Glow; // high-, mid-, low-nibble
    uint8_t u8Bhigh, u8Bmid, u8Blow; // high-, mid-, low-nibble
   
    u32R = WS2812_byte2binary(((u32Color>>8)&0xFF)/u32LedIntensity);
    u8Rhigh = u32R >> 16;
    u8Rmid  = u32R >> 8;
    u8Rlow  = u32R >> 0;
    
    u32G = WS2812_byte2binary((u32Color&0xFF)/u32LedIntensity);
    u8Ghigh = u32G >> 16;
    u8Gmid  = u32G >> 8;
    u8Glow  = u32G >> 0;
    
    u32B = WS2812_byte2binary(((u32Color>>16)&0xFF)/u32LedIntensity);
    u8Bhigh = u32B >> 16;
    u8Bmid  = u32B >> 8;
    u8Blow  = u32B >> 0; 
    
    pu8buffer = &u8WS2812_BUFFER[0];
    
    for (u16cnt = 0; u16cnt <  WS2812_CNT; u16cnt++)
    {
        *pu8buffer++ = u8Rhigh;  
        *pu8buffer++ = u8Rmid;  
        *pu8buffer++ = u8Rlow;  
        *pu8buffer++ = u8Ghigh;  
        *pu8buffer++ = u8Gmid;  
        *pu8buffer++ = u8Glow; 
        *pu8buffer++ = u8Bhigh;  
        *pu8buffer++ = u8Bmid;  
        *pu8buffer++ = u8Blow; 
    }
}

#ifdef CY_SCB_UART_H
    void UART_binary(uint8_t byte)
    {
        uint8_t i;
        
        for (i=0; i<8; i++)
        {
            if (0x80 & byte)
            {
                UART_UartPutChar('1');
            }
            else
            {
                 UART_UartPutChar('0');
            }  
            byte = byte<<1;
        } 
    }

    void debug_send_byte(uint8_t data)
    {
        StripLights_SpiUartWriteTxData(data);
        UART_binary(data);
        UART_UartPutChar('\n');
    }
#endif

void StripLights_Trigger()
{ 
    uint16_t u16cnt;
    uint8_t *pu8buffer;
    
    StripLights_INTR_TX_MASK_REG |= StripLights_INTR_TX_NOT_FULL;   // Enable TX_NOT_FULL interrupts
    
    #ifdef CY_SCB_UART_H     
        UART_UartPutString("\nTrigger\n");
    #endif

    // Prefill the FIFO to avoid any timing issues
    pu8buffer = &u8WS2812_BUFFER[0];
    StripLights_SpiUartWriteTxData(0);
    for (u16cnt = 0; u16cnt < (WS2812_CNT * 9); u16cnt++)
    {
        StripLights_SpiUartWriteTxData(*pu8buffer++);
        //debug_send_byte(*pu8buffer++);
    }
    CyDelay(10); // WS2812 Reset
}

//
//
// u16pos       : Position of LED 0 .. (WS2812_CNT - 1)
// u32color     : Color format - - b b r r g g 
//
void StripLights_Pixel(uint16_t u16pos, uint32_t u32color)
{
    uint8_t *pu8buffer;
    uint32_t u32R, u32G, u32B;
    uint8_t u8Rhigh, u8Rmid, u8Rlow; // high-, mid-, low-nibble
    uint8_t u8Ghigh, u8Gmid, u8Glow; // high-, mid-, low-nibble
    uint8_t u8Bhigh, u8Bmid, u8Blow; // high-, mid-, low-nibble
    
    if (u32LedIntensity == 0)
    { 
        u32R = WS2812_byte2binary(0);
        u8Rhigh = u32R >> 16; u8Ghigh = u8Rhigh; u8Bhigh = u8Rhigh;
        u8Rmid  = u32R >> 8;  u8Gmid  = u8Rmid;  u8Bmid  = u8Rmid;
        u8Rlow  = u32R >> 0;  u8Glow  = u8Rlow;  u8Blow  = u8Rlow;
    }
    else
    {
        u32R = WS2812_byte2binary(((u32color>>8)&0xFF)/u32LedIntensity);
        u8Rhigh = u32R >> 16;
        u8Rmid  = u32R >> 8;
        u8Rlow  = u32R >> 0;
        
        u32G = WS2812_byte2binary((u32color&0xFF)/u32LedIntensity);
        u8Ghigh = u32G >> 16;
        u8Gmid  = u32G >> 8;
        u8Glow  = u32G >> 0;
        
        u32B = WS2812_byte2binary(((u32color>>16)&0xFF)/u32LedIntensity);
        u8Bhigh = u32B >> 16;
        u8Bmid  = u32B >> 8;
        u8Blow  = u32B >> 0; 
    }
    
    pu8buffer = &u8WS2812_BUFFER[(9*u16pos)];
    *pu8buffer++ = u8Rhigh;  
    *pu8buffer++ = u8Rmid;  
    *pu8buffer++ = u8Rlow;  
    *pu8buffer++ = u8Ghigh;  
    *pu8buffer++ = u8Gmid;  
    *pu8buffer++ = u8Glow; 
    *pu8buffer++ = u8Bhigh;  
    *pu8buffer++ = u8Bmid;  
    *pu8buffer++ = u8Blow; 
}

/**
 ******************************************************************************
 **  CUBE Functions
 ******************************************************************************/

#define DENSITY_TOUCHED   (0x00FFFFFFu)   /**<  Full brightness of each color: - - b b r r g g */
#define DENSITY_UNTOUCHED (0x00303030u)   /**<  Reduced brightness of each color: - - b b r r g g */

/*! Format:  - - b b g g r r  */
//const uint32_t U32COLOR[6] = { 0x00FFFF00, 0x0000FFFF, 0x0000FF00, 0x00FFFFFF, 0x000000FF, 0x00FF0000 }; /**< touched color (high brightness) */

#define CYAN    (0x00FFFF00)
#define ORANGE  (0x000080FF)
#define YELLOW  (0x0000FFFF)
#define GREEN   (0x0000FF00)
#define WHITE   (0x00FFFFFF)
#define RED     (0x000000FF)
#define BLUE    (0x00FF0000)
#define BLACK   (0x00000000)

uint32_t U32COLOR[6];

uint32_t u32CubeLedColor[54]; 


void CubeLED_Init()
{
    uint8_t u8page, u8led;
    
    U32COLOR[0] = GREEN;
    U32COLOR[1] = RED;
    U32COLOR[2] = YELLOW;
    U32COLOR[3] = BLUE;
    U32COLOR[4] = ORANGE;   
    U32COLOR[5] = WHITE;
    
    for (u8page=0; u8page<6; u8page++)
    {
        for (u8led=0; u8led<9; u8led++)
        {
            u32CubeLedColor[(u8page*9)+u8led] = U32COLOR[u8page];
        }
    }
}

void CubeLED_setcolor(uint8_t led, uint32_t color)
{
    u32CubeLedColor[led] = color;
    StripLights_Pixel(led, color); // - - b b r r g g 
}

/**
 ******************************************************************************
 **  \brief       Drive Cube LEDs to its related value.
 **
 **  \param [in]  none
 **  \return      Nothing
 ******************************************************************************/
void CubeLED_Refresh(void)
{
    uint8_t u8led;
    for (u8led=0; u8led<54; u8led++)
    {
        StripLights_Pixel(u8led, u32CubeLedColor[u8led]);
    }  
}

///**
// ******************************************************************************
// **  \brief       Moves element 1 toward 0 (1 step only)
// **               Call 3 times for complete movement!
// **
// **  \param [in]  none
// **  \return      Nothing
// ******************************************************************************/
void CubeMove_01_to_00(void)
{
    uint32_t u32temp;
    u32temp = u32CubeLedColor[ 0];
    u32CubeLedColor[ 0] = u32CubeLedColor[ 1];  StripLights_Pixel( 0, u32CubeLedColor[ 0]);
    u32CubeLedColor[ 1] = u32CubeLedColor[ 2];  StripLights_Pixel( 1, u32CubeLedColor[ 1]);
    u32CubeLedColor[ 2] = u32CubeLedColor[11];  StripLights_Pixel( 2, u32CubeLedColor[ 2]);
    u32CubeLedColor[11] = u32CubeLedColor[12];  StripLights_Pixel(11, u32CubeLedColor[11]);
    u32CubeLedColor[12] = u32CubeLedColor[17];  StripLights_Pixel(12, u32CubeLedColor[12]);
    u32CubeLedColor[17] = u32CubeLedColor[27];  StripLights_Pixel(17, u32CubeLedColor[17]);
    u32CubeLedColor[27] = u32CubeLedColor[28];  StripLights_Pixel(27, u32CubeLedColor[27]);
    u32CubeLedColor[28] = u32CubeLedColor[29];  StripLights_Pixel(28, u32CubeLedColor[28]);
    u32CubeLedColor[29] = u32CubeLedColor[38];  StripLights_Pixel(29, u32CubeLedColor[29]);
    u32CubeLedColor[38] = u32CubeLedColor[39];  StripLights_Pixel(38, u32CubeLedColor[38]);
    u32CubeLedColor[39] = u32CubeLedColor[44];  StripLights_Pixel(39, u32CubeLedColor[39]);
    u32CubeLedColor[44] = u32temp;              StripLights_Pixel(44, u32CubeLedColor[44]);

    if ((u32CubeMoveSteps!=2) && (u32CubeMoveSteps!=5))
    {
        //Aussenwand
        u32temp = u32CubeLedColor[26];
        u32CubeLedColor[26] = u32CubeLedColor[21];  StripLights_Pixel(26, u32CubeLedColor[26]);
        u32CubeLedColor[21] = u32CubeLedColor[20];  StripLights_Pixel(21, u32CubeLedColor[21]);
        u32CubeLedColor[20] = u32CubeLedColor[19];  StripLights_Pixel(20, u32CubeLedColor[20]);
        u32CubeLedColor[19] = u32CubeLedColor[18];  StripLights_Pixel(19, u32CubeLedColor[19]);
        u32CubeLedColor[18] = u32CubeLedColor[23];  StripLights_Pixel(18, u32CubeLedColor[18]);
        u32CubeLedColor[23] = u32CubeLedColor[24];  StripLights_Pixel(23, u32CubeLedColor[23]);
        u32CubeLedColor[24] = u32CubeLedColor[25];  StripLights_Pixel(24, u32CubeLedColor[24]);
        u32CubeLedColor[25] = u32temp;              StripLights_Pixel(25, u32CubeLedColor[25]);
    }
}

void CubeMove_00_to_01(void)
{
    uint32_t u32temp;
    u32temp = u32CubeLedColor[ 1];
    u32CubeLedColor[ 1] = u32CubeLedColor[ 0];  StripLights_Pixel( 1, u32CubeLedColor[ 1]);
    u32CubeLedColor[ 0] = u32CubeLedColor[44];  StripLights_Pixel( 0, u32CubeLedColor[ 0]);
    u32CubeLedColor[44] = u32CubeLedColor[39];  StripLights_Pixel(44, u32CubeLedColor[44]);
    u32CubeLedColor[39] = u32CubeLedColor[38];  StripLights_Pixel(39, u32CubeLedColor[39]);
    u32CubeLedColor[38] = u32CubeLedColor[29];  StripLights_Pixel(38, u32CubeLedColor[38]);
    u32CubeLedColor[29] = u32CubeLedColor[28];  StripLights_Pixel(29, u32CubeLedColor[29]);
    u32CubeLedColor[28] = u32CubeLedColor[27];  StripLights_Pixel(28, u32CubeLedColor[28]);
    u32CubeLedColor[27] = u32CubeLedColor[17];  StripLights_Pixel(27, u32CubeLedColor[27]);
    u32CubeLedColor[17] = u32CubeLedColor[12];  StripLights_Pixel(17, u32CubeLedColor[17]);
    u32CubeLedColor[12] = u32CubeLedColor[11];  StripLights_Pixel(12, u32CubeLedColor[12]);
    u32CubeLedColor[11] = u32CubeLedColor[ 2];  StripLights_Pixel(11, u32CubeLedColor[11]);
    u32CubeLedColor[ 2] = u32temp;              StripLights_Pixel( 2, u32CubeLedColor[ 2]);

    if ((u32CubeMoveSteps!=2) && (u32CubeMoveSteps!=5))
    {
        //Aussenwand
        u32temp = u32CubeLedColor[21];
        u32CubeLedColor[21] = u32CubeLedColor[26];  StripLights_Pixel(21, u32CubeLedColor[21]);
        u32CubeLedColor[26] = u32CubeLedColor[25];  StripLights_Pixel(26, u32CubeLedColor[26]);
        u32CubeLedColor[25] = u32CubeLedColor[24];  StripLights_Pixel(25, u32CubeLedColor[25]);
        u32CubeLedColor[24] = u32CubeLedColor[23];  StripLights_Pixel(24, u32CubeLedColor[24]);
        u32CubeLedColor[23] = u32CubeLedColor[18];  StripLights_Pixel(23, u32CubeLedColor[23]);
        u32CubeLedColor[18] = u32CubeLedColor[19];  StripLights_Pixel(18, u32CubeLedColor[18]);
        u32CubeLedColor[19] = u32CubeLedColor[20];  StripLights_Pixel(19, u32CubeLedColor[19]);
        u32CubeLedColor[20] = u32temp;  StripLights_Pixel(20, u32CubeLedColor[20]);
    }
}

void CubeMove_04_to_05(void)
{
    uint32_t u32temp;
    u32temp = u32CubeLedColor[ 5];
    u32CubeLedColor[ 5] = u32CubeLedColor[ 4];  StripLights_Pixel( 5, u32CubeLedColor[ 5]);
    u32CubeLedColor[ 4] = u32CubeLedColor[ 3];  StripLights_Pixel( 4, u32CubeLedColor[ 4]);
    u32CubeLedColor[ 3] = u32CubeLedColor[10];  StripLights_Pixel( 3, u32CubeLedColor[ 3]);
    u32CubeLedColor[10] = u32CubeLedColor[13];  StripLights_Pixel(10, u32CubeLedColor[10]);
    u32CubeLedColor[13] = u32CubeLedColor[16];  StripLights_Pixel(13, u32CubeLedColor[13]);
    u32CubeLedColor[16] = u32CubeLedColor[32];  StripLights_Pixel(16, u32CubeLedColor[16]);
    u32CubeLedColor[32] = u32CubeLedColor[31];  StripLights_Pixel(32, u32CubeLedColor[32]);
    u32CubeLedColor[31] = u32CubeLedColor[30];  StripLights_Pixel(31, u32CubeLedColor[31]);
    u32CubeLedColor[30] = u32CubeLedColor[37];  StripLights_Pixel(30, u32CubeLedColor[30]);
    u32CubeLedColor[37] = u32CubeLedColor[40];  StripLights_Pixel(37, u32CubeLedColor[37]);
    u32CubeLedColor[40] = u32CubeLedColor[43];  StripLights_Pixel(40, u32CubeLedColor[40]);
    u32CubeLedColor[43] = u32temp;              StripLights_Pixel(43, u32CubeLedColor[43]);
}

void CubeMove_05_to_04(void)
{
    uint32_t u32temp;
    u32temp = u32CubeLedColor[ 4];
    u32CubeLedColor[ 4] = u32CubeLedColor[ 5];  StripLights_Pixel( 4, u32CubeLedColor[ 4]);
    u32CubeLedColor[ 5] = u32CubeLedColor[43];  StripLights_Pixel( 5, u32CubeLedColor[ 5]);
    u32CubeLedColor[43] = u32CubeLedColor[40];  StripLights_Pixel(43, u32CubeLedColor[43]);
    u32CubeLedColor[40] = u32CubeLedColor[37];  StripLights_Pixel(40, u32CubeLedColor[40]);
    u32CubeLedColor[37] = u32CubeLedColor[30];  StripLights_Pixel(37, u32CubeLedColor[37]);
    u32CubeLedColor[30] = u32CubeLedColor[31];  StripLights_Pixel(30, u32CubeLedColor[30]);
    u32CubeLedColor[31] = u32CubeLedColor[32];  StripLights_Pixel(31, u32CubeLedColor[31]);
    u32CubeLedColor[32] = u32CubeLedColor[16];  StripLights_Pixel(32, u32CubeLedColor[32]);
    u32CubeLedColor[16] = u32CubeLedColor[13];  StripLights_Pixel(16, u32CubeLedColor[16]);
    u32CubeLedColor[13] = u32CubeLedColor[10];  StripLights_Pixel(13, u32CubeLedColor[13]);
    u32CubeLedColor[10] = u32CubeLedColor[ 3];  StripLights_Pixel(10, u32CubeLedColor[10]);
    u32CubeLedColor[ 3] = u32temp;              StripLights_Pixel( 3, u32CubeLedColor[ 3]);
}

void CubeMove_07_to_06(void)
{
    uint32_t u32temp;
    u32temp = u32CubeLedColor[ 6];
    u32CubeLedColor[ 6] = u32CubeLedColor[ 7];  StripLights_Pixel( 6, u32CubeLedColor[ 6]);
    u32CubeLedColor[ 7] = u32CubeLedColor[ 8];  StripLights_Pixel( 7, u32CubeLedColor[ 7]);
    u32CubeLedColor[ 8] = u32CubeLedColor[ 9];  StripLights_Pixel( 8, u32CubeLedColor[ 8]);
    u32CubeLedColor[ 9] = u32CubeLedColor[14];  StripLights_Pixel( 9, u32CubeLedColor[ 9]);
    u32CubeLedColor[14] = u32CubeLedColor[15];  StripLights_Pixel(14, u32CubeLedColor[14]);
    u32CubeLedColor[15] = u32CubeLedColor[33];  StripLights_Pixel(15, u32CubeLedColor[15]);
    u32CubeLedColor[33] = u32CubeLedColor[34];  StripLights_Pixel(33, u32CubeLedColor[33]);
    u32CubeLedColor[34] = u32CubeLedColor[35];  StripLights_Pixel(34, u32CubeLedColor[34]);
    u32CubeLedColor[35] = u32CubeLedColor[36];  StripLights_Pixel(35, u32CubeLedColor[35]);
    u32CubeLedColor[36] = u32CubeLedColor[41];  StripLights_Pixel(36, u32CubeLedColor[36]);
    u32CubeLedColor[41] = u32CubeLedColor[42];  StripLights_Pixel(41, u32CubeLedColor[41]);
    u32CubeLedColor[42] = u32temp;              StripLights_Pixel(42, u32CubeLedColor[42]);

    if ((u32CubeMoveSteps!=2) && (u32CubeMoveSteps!=5))
    {
        //Aussenwand
        u32temp = u32CubeLedColor[47];
        u32CubeLedColor[47] = u32CubeLedColor[48];  StripLights_Pixel(47, u32CubeLedColor[47]);
        u32CubeLedColor[48] = u32CubeLedColor[53];  StripLights_Pixel(48, u32CubeLedColor[48]);
        u32CubeLedColor[53] = u32CubeLedColor[52];  StripLights_Pixel(53, u32CubeLedColor[53]);
        u32CubeLedColor[52] = u32CubeLedColor[51];  StripLights_Pixel(52, u32CubeLedColor[52]);
        u32CubeLedColor[51] = u32CubeLedColor[50];  StripLights_Pixel(51, u32CubeLedColor[51]);
        u32CubeLedColor[50] = u32CubeLedColor[45];  StripLights_Pixel(50, u32CubeLedColor[50]);
        u32CubeLedColor[45] = u32CubeLedColor[46];  StripLights_Pixel(45, u32CubeLedColor[45]);
        u32CubeLedColor[46] = u32temp;  StripLights_Pixel(46, u32CubeLedColor[46]);
    }
}

void CubeMove_06_to_07(void)
{
    uint32_t u32temp;
    u32temp = u32CubeLedColor[ 7];
    u32CubeLedColor[ 7] = u32CubeLedColor[ 6];  StripLights_Pixel( 7, u32CubeLedColor[ 7]);
    u32CubeLedColor[ 6] = u32CubeLedColor[42];  StripLights_Pixel( 6, u32CubeLedColor[ 6]);
    u32CubeLedColor[42] = u32CubeLedColor[41];  StripLights_Pixel(42, u32CubeLedColor[42]);
    u32CubeLedColor[41] = u32CubeLedColor[36];  StripLights_Pixel(41, u32CubeLedColor[41]);
    u32CubeLedColor[36] = u32CubeLedColor[35];  StripLights_Pixel(36, u32CubeLedColor[36]);
    u32CubeLedColor[35] = u32CubeLedColor[34];  StripLights_Pixel(35, u32CubeLedColor[35]);
    u32CubeLedColor[34] = u32CubeLedColor[33];  StripLights_Pixel(34, u32CubeLedColor[34]);
    u32CubeLedColor[33] = u32CubeLedColor[15];  StripLights_Pixel(33, u32CubeLedColor[33]);
    u32CubeLedColor[15] = u32CubeLedColor[14];  StripLights_Pixel(15, u32CubeLedColor[15]);
    u32CubeLedColor[14] = u32CubeLedColor[ 9];  StripLights_Pixel(14, u32CubeLedColor[14]);
    u32CubeLedColor[ 9] = u32CubeLedColor[ 8];  StripLights_Pixel( 9, u32CubeLedColor[ 9]);
    u32CubeLedColor[ 8] = u32temp;              StripLights_Pixel( 8, u32CubeLedColor[ 8]);
    
    if ((u32CubeMoveSteps!=2) && (u32CubeMoveSteps!=5))
    {
        //Aussenwand
        u32temp = u32CubeLedColor[48];
        u32CubeLedColor[48] = u32CubeLedColor[47];  StripLights_Pixel(48, u32CubeLedColor[48]);
        u32CubeLedColor[47] = u32CubeLedColor[46];  StripLights_Pixel(47, u32CubeLedColor[47]);
        u32CubeLedColor[46] = u32CubeLedColor[45];  StripLights_Pixel(46, u32CubeLedColor[46]);
        u32CubeLedColor[45] = u32CubeLedColor[50];  StripLights_Pixel(45, u32CubeLedColor[45]);
        u32CubeLedColor[50] = u32CubeLedColor[51];  StripLights_Pixel(50, u32CubeLedColor[50]);
        u32CubeLedColor[51] = u32CubeLedColor[52];  StripLights_Pixel(51, u32CubeLedColor[51]);
        u32CubeLedColor[52] = u32CubeLedColor[53];  StripLights_Pixel(52, u32CubeLedColor[52]);
        u32CubeLedColor[53] = u32temp;  StripLights_Pixel(53, u32CubeLedColor[53]);
    }
}

void CubeMove_00_to_05(void)
{
    uint32_t u32temp;
    u32temp = u32CubeLedColor[ 5];
    u32CubeLedColor[ 5] = u32CubeLedColor[ 0];  StripLights_Pixel( 5, u32CubeLedColor[ 5]);
    u32CubeLedColor[ 0] = u32CubeLedColor[26];  StripLights_Pixel( 0, u32CubeLedColor[ 0]);
    u32CubeLedColor[26] = u32CubeLedColor[25];  StripLights_Pixel(26, u32CubeLedColor[26]);
    u32CubeLedColor[25] = u32CubeLedColor[24];  StripLights_Pixel(25, u32CubeLedColor[25]);
    u32CubeLedColor[24] = u32CubeLedColor[29];  StripLights_Pixel(24, u32CubeLedColor[24]);
    u32CubeLedColor[29] = u32CubeLedColor[30];  StripLights_Pixel(29, u32CubeLedColor[29]);
    u32CubeLedColor[30] = u32CubeLedColor[35];  StripLights_Pixel(30, u32CubeLedColor[30]);
    u32CubeLedColor[35] = u32CubeLedColor[45];  StripLights_Pixel(35, u32CubeLedColor[35]);
    u32CubeLedColor[45] = u32CubeLedColor[46];  StripLights_Pixel(45, u32CubeLedColor[45]);
    u32CubeLedColor[46] = u32CubeLedColor[47];  StripLights_Pixel(46, u32CubeLedColor[46]);
    u32CubeLedColor[47] = u32CubeLedColor[ 6];  StripLights_Pixel(47, u32CubeLedColor[47]);
    u32CubeLedColor[ 6] = u32temp;              StripLights_Pixel( 6, u32CubeLedColor[ 6]);

    if ((u32CubeMoveSteps!=2) && (u32CubeMoveSteps!=5))
    {
        //Aussenwand
        u32temp = u32CubeLedColor[43];
        u32CubeLedColor[43] = u32CubeLedColor[44];  StripLights_Pixel(43, u32CubeLedColor[43]);
        u32CubeLedColor[44] = u32CubeLedColor[39];  StripLights_Pixel(44, u32CubeLedColor[44]);
        u32CubeLedColor[39] = u32CubeLedColor[38];  StripLights_Pixel(39, u32CubeLedColor[39]);
        u32CubeLedColor[38] = u32CubeLedColor[37];  StripLights_Pixel(38, u32CubeLedColor[38]);
        u32CubeLedColor[37] = u32CubeLedColor[36];  StripLights_Pixel(37, u32CubeLedColor[37]);
        u32CubeLedColor[36] = u32CubeLedColor[41];  StripLights_Pixel(36, u32CubeLedColor[36]);
        u32CubeLedColor[41] = u32CubeLedColor[42];  StripLights_Pixel(41, u32CubeLedColor[41]);
        u32CubeLedColor[42] = u32temp;  StripLights_Pixel(42, u32CubeLedColor[42]);
    }
}

void CubeMove_05_to_00(void)
{
    uint32_t u32temp;
    u32temp = u32CubeLedColor[ 0];
    u32CubeLedColor[ 0] = u32CubeLedColor[ 5];  StripLights_Pixel( 0, u32CubeLedColor[ 0]);
    u32CubeLedColor[ 5] = u32CubeLedColor[ 6];  StripLights_Pixel( 5, u32CubeLedColor[ 5]);
    u32CubeLedColor[ 6] = u32CubeLedColor[47];  StripLights_Pixel( 6, u32CubeLedColor[ 6]);
    u32CubeLedColor[47] = u32CubeLedColor[46];  StripLights_Pixel(47, u32CubeLedColor[47]);
    u32CubeLedColor[46] = u32CubeLedColor[45];  StripLights_Pixel(46, u32CubeLedColor[46]);
    u32CubeLedColor[45] = u32CubeLedColor[35];  StripLights_Pixel(45, u32CubeLedColor[45]);
    u32CubeLedColor[35] = u32CubeLedColor[30];  StripLights_Pixel(35, u32CubeLedColor[35]);
    u32CubeLedColor[30] = u32CubeLedColor[29];  StripLights_Pixel(30, u32CubeLedColor[30]);
    u32CubeLedColor[29] = u32CubeLedColor[24];  StripLights_Pixel(29, u32CubeLedColor[29]);
    u32CubeLedColor[24] = u32CubeLedColor[25];  StripLights_Pixel(24, u32CubeLedColor[24]);
    u32CubeLedColor[25] = u32CubeLedColor[26];  StripLights_Pixel(25, u32CubeLedColor[25]);
    u32CubeLedColor[26] = u32temp;              StripLights_Pixel(26, u32CubeLedColor[26]);

    if ((u32CubeMoveSteps!=2) && (u32CubeMoveSteps!=5))
    {    
        //Aussenwand
        u32temp = u32CubeLedColor[44];
        u32CubeLedColor[44] = u32CubeLedColor[43];  StripLights_Pixel(44, u32CubeLedColor[44]);
        u32CubeLedColor[43] = u32CubeLedColor[42];  StripLights_Pixel(43, u32CubeLedColor[43]);
        u32CubeLedColor[42] = u32CubeLedColor[41];  StripLights_Pixel(42, u32CubeLedColor[42]);
        u32CubeLedColor[41] = u32CubeLedColor[36];  StripLights_Pixel(41, u32CubeLedColor[41]);
        u32CubeLedColor[36] = u32CubeLedColor[37];  StripLights_Pixel(36, u32CubeLedColor[36]);
        u32CubeLedColor[37] = u32CubeLedColor[38];  StripLights_Pixel(37, u32CubeLedColor[37]);
        u32CubeLedColor[38] = u32CubeLedColor[39];  StripLights_Pixel(38, u32CubeLedColor[38]);
        u32CubeLedColor[39] = u32temp;  StripLights_Pixel(39, u32CubeLedColor[39]);
    }
}

void CubeMove_01_to_04(void)
{
    uint32_t u32temp;
    u32temp = u32CubeLedColor[ 4];
    u32CubeLedColor[ 4] = u32CubeLedColor[ 1];  StripLights_Pixel( 4, u32CubeLedColor[ 4]);
    u32CubeLedColor[ 1] = u32CubeLedColor[21];  StripLights_Pixel( 1, u32CubeLedColor[ 1]);
    u32CubeLedColor[21] = u32CubeLedColor[22];  StripLights_Pixel(21, u32CubeLedColor[21]);
    u32CubeLedColor[22] = u32CubeLedColor[23];  StripLights_Pixel(22, u32CubeLedColor[22]);
    u32CubeLedColor[23] = u32CubeLedColor[28];  StripLights_Pixel(23, u32CubeLedColor[23]);
    u32CubeLedColor[28] = u32CubeLedColor[31];  StripLights_Pixel(28, u32CubeLedColor[28]);
    u32CubeLedColor[31] = u32CubeLedColor[34];  StripLights_Pixel(31, u32CubeLedColor[31]);
    u32CubeLedColor[34] = u32CubeLedColor[50];  StripLights_Pixel(34, u32CubeLedColor[34]);
    u32CubeLedColor[50] = u32CubeLedColor[49];  StripLights_Pixel(50, u32CubeLedColor[50]);
    u32CubeLedColor[49] = u32CubeLedColor[48];  StripLights_Pixel(49, u32CubeLedColor[49]);
    u32CubeLedColor[48] = u32CubeLedColor[ 7];  StripLights_Pixel(48, u32CubeLedColor[48]);
    u32CubeLedColor[ 7] = u32temp;              StripLights_Pixel( 7, u32CubeLedColor[ 7]);
}

void CubeMove_04_to_01(void)
{
    uint32_t u32temp;
    u32temp = u32CubeLedColor[ 1];
    u32CubeLedColor[ 1] = u32CubeLedColor[ 4];  StripLights_Pixel( 1, u32CubeLedColor[ 1]);
    u32CubeLedColor[ 4] = u32CubeLedColor[ 7];  StripLights_Pixel( 4, u32CubeLedColor[ 4]);
    u32CubeLedColor[ 7] = u32CubeLedColor[48];  StripLights_Pixel( 7, u32CubeLedColor[ 7]);
    u32CubeLedColor[48] = u32CubeLedColor[49];  StripLights_Pixel(48, u32CubeLedColor[48]);
    u32CubeLedColor[49] = u32CubeLedColor[50];  StripLights_Pixel(49, u32CubeLedColor[49]);
    u32CubeLedColor[50] = u32CubeLedColor[34];  StripLights_Pixel(50, u32CubeLedColor[50]);
    u32CubeLedColor[34] = u32CubeLedColor[31];  StripLights_Pixel(34, u32CubeLedColor[34]);
    u32CubeLedColor[31] = u32CubeLedColor[28];  StripLights_Pixel(31, u32CubeLedColor[31]);
    u32CubeLedColor[28] = u32CubeLedColor[23];  StripLights_Pixel(28, u32CubeLedColor[28]);
    u32CubeLedColor[23] = u32CubeLedColor[22];  StripLights_Pixel(23, u32CubeLedColor[23]);
    u32CubeLedColor[22] = u32CubeLedColor[21];  StripLights_Pixel(22, u32CubeLedColor[22]);
    u32CubeLedColor[21] = u32temp;              StripLights_Pixel(21, u32CubeLedColor[21]);
}

void CubeMove_02_to_03(void)
{
    uint32_t u32temp;
    u32temp = u32CubeLedColor[ 3];
    u32CubeLedColor[ 3] = u32CubeLedColor[ 2];  StripLights_Pixel( 3, u32CubeLedColor[ 3]);
    u32CubeLedColor[ 2] = u32CubeLedColor[20];  StripLights_Pixel( 2, u32CubeLedColor[ 2]);
    u32CubeLedColor[20] = u32CubeLedColor[19];  StripLights_Pixel(20, u32CubeLedColor[20]);
    u32CubeLedColor[19] = u32CubeLedColor[18];  StripLights_Pixel(19, u32CubeLedColor[19]);
    u32CubeLedColor[18] = u32CubeLedColor[27];  StripLights_Pixel(18, u32CubeLedColor[18]);
    u32CubeLedColor[27] = u32CubeLedColor[32];  StripLights_Pixel(27, u32CubeLedColor[27]);
    u32CubeLedColor[32] = u32CubeLedColor[33];  StripLights_Pixel(32, u32CubeLedColor[32]);
    u32CubeLedColor[33] = u32CubeLedColor[51];  StripLights_Pixel(33, u32CubeLedColor[33]);
    u32CubeLedColor[51] = u32CubeLedColor[52];  StripLights_Pixel(51, u32CubeLedColor[51]);
    u32CubeLedColor[52] = u32CubeLedColor[53];  StripLights_Pixel(52, u32CubeLedColor[52]);
    u32CubeLedColor[53] = u32CubeLedColor[ 8];  StripLights_Pixel(53, u32CubeLedColor[53]);
    u32CubeLedColor[ 8] = u32temp;              StripLights_Pixel( 8, u32CubeLedColor[ 8]);

    if ((u32CubeMoveSteps!=2) && (u32CubeMoveSteps!=5))
    {    
        //Aussenwand
        u32temp = u32CubeLedColor[10];
        u32CubeLedColor[10] = u32CubeLedColor[11];  StripLights_Pixel(10, u32CubeLedColor[10]);
        u32CubeLedColor[11] = u32CubeLedColor[12];  StripLights_Pixel(11, u32CubeLedColor[11]);
        u32CubeLedColor[12] = u32CubeLedColor[17];  StripLights_Pixel(12, u32CubeLedColor[12]);
        u32CubeLedColor[17] = u32CubeLedColor[16];  StripLights_Pixel(17, u32CubeLedColor[17]);
        u32CubeLedColor[16] = u32CubeLedColor[15];  StripLights_Pixel(16, u32CubeLedColor[16]);
        u32CubeLedColor[15] = u32CubeLedColor[14];  StripLights_Pixel(15, u32CubeLedColor[15]);
        u32CubeLedColor[14] = u32CubeLedColor[ 9];  StripLights_Pixel(14, u32CubeLedColor[14]);
        u32CubeLedColor[ 9] = u32temp;  StripLights_Pixel( 9, u32CubeLedColor[ 9]);
    }
}

void CubeMove_03_to_02(void)
{
    uint32_t u32temp;
    u32temp = u32CubeLedColor[ 2];
    u32CubeLedColor[ 2] = u32CubeLedColor[ 3];  StripLights_Pixel( 2, u32CubeLedColor[ 2]);
    u32CubeLedColor[ 3] = u32CubeLedColor[ 8];  StripLights_Pixel( 3, u32CubeLedColor[ 3]);
    u32CubeLedColor[ 8] = u32CubeLedColor[53];  StripLights_Pixel( 8, u32CubeLedColor[ 8]);
    u32CubeLedColor[53] = u32CubeLedColor[52];  StripLights_Pixel(53, u32CubeLedColor[53]);
    u32CubeLedColor[52] = u32CubeLedColor[51];  StripLights_Pixel(52, u32CubeLedColor[52]);
    u32CubeLedColor[51] = u32CubeLedColor[33];  StripLights_Pixel(51, u32CubeLedColor[51]);
    u32CubeLedColor[33] = u32CubeLedColor[32];  StripLights_Pixel(33, u32CubeLedColor[33]);
    u32CubeLedColor[32] = u32CubeLedColor[27];  StripLights_Pixel(32, u32CubeLedColor[32]);
    u32CubeLedColor[27] = u32CubeLedColor[18];  StripLights_Pixel(27, u32CubeLedColor[27]);
    u32CubeLedColor[18] = u32CubeLedColor[19];  StripLights_Pixel(18, u32CubeLedColor[18]);
    u32CubeLedColor[19] = u32CubeLedColor[20];  StripLights_Pixel(19, u32CubeLedColor[19]);
    u32CubeLedColor[20] = u32temp;              StripLights_Pixel(20, u32CubeLedColor[20]);

    if ((u32CubeMoveSteps!=2) && (u32CubeMoveSteps!=5))
    {
        //Aussenwand
        u32temp = u32CubeLedColor[11];
        u32CubeLedColor[11] = u32CubeLedColor[10];  StripLights_Pixel(11, u32CubeLedColor[11]);
        u32CubeLedColor[10] = u32CubeLedColor[ 9];  StripLights_Pixel(10, u32CubeLedColor[10]);
        u32CubeLedColor[ 9] = u32CubeLedColor[14];  StripLights_Pixel( 9, u32CubeLedColor[ 9]);
        u32CubeLedColor[14] = u32CubeLedColor[15];  StripLights_Pixel(14, u32CubeLedColor[14]);
        u32CubeLedColor[15] = u32CubeLedColor[16];  StripLights_Pixel(15, u32CubeLedColor[15]);
        u32CubeLedColor[16] = u32CubeLedColor[17];  StripLights_Pixel(16, u32CubeLedColor[16]);
        u32CubeLedColor[17] = u32CubeLedColor[12];  StripLights_Pixel(17, u32CubeLedColor[17]);
        u32CubeLedColor[12] = u32temp;  StripLights_Pixel(12, u32CubeLedColor[12]);
    }
}

void CubeMove_11_to_10(void)
{
    uint32_t u32temp;
    u32temp = u32CubeLedColor[10];
    u32CubeLedColor[10] = u32CubeLedColor[11];  StripLights_Pixel(10, u32CubeLedColor[10]);
    u32CubeLedColor[11] = u32CubeLedColor[20];  StripLights_Pixel(11, u32CubeLedColor[11]);
    u32CubeLedColor[20] = u32CubeLedColor[21];  StripLights_Pixel(20, u32CubeLedColor[20]);
    u32CubeLedColor[21] = u32CubeLedColor[26];  StripLights_Pixel(21, u32CubeLedColor[21]);
    u32CubeLedColor[26] = u32CubeLedColor[44];  StripLights_Pixel(26, u32CubeLedColor[26]);
    u32CubeLedColor[44] = u32CubeLedColor[43];  StripLights_Pixel(44, u32CubeLedColor[44]);
    u32CubeLedColor[43] = u32CubeLedColor[42];  StripLights_Pixel(43, u32CubeLedColor[43]);
    u32CubeLedColor[42] = u32CubeLedColor[47];  StripLights_Pixel(42, u32CubeLedColor[42]);
    u32CubeLedColor[47] = u32CubeLedColor[48];  StripLights_Pixel(47, u32CubeLedColor[47]);
    u32CubeLedColor[48] = u32CubeLedColor[53];  StripLights_Pixel(48, u32CubeLedColor[48]);
    u32CubeLedColor[53] = u32CubeLedColor[ 9];  StripLights_Pixel(53, u32CubeLedColor[53]);
    u32CubeLedColor[ 9] = u32temp;              StripLights_Pixel( 9, u32CubeLedColor[ 9]);

    if ((u32CubeMoveSteps!=2) && (u32CubeMoveSteps!=5))
    {    
        //Aussenwand
        u32temp = u32CubeLedColor[ 3];
        u32CubeLedColor[ 3] = u32CubeLedColor[ 2];  StripLights_Pixel( 3, u32CubeLedColor[ 3]);
        u32CubeLedColor[ 2] = u32CubeLedColor[ 1];  StripLights_Pixel( 2, u32CubeLedColor[ 2]);
        u32CubeLedColor[ 1] = u32CubeLedColor[ 0];  StripLights_Pixel( 1, u32CubeLedColor[ 1]);
        u32CubeLedColor[ 0] = u32CubeLedColor[ 5];  StripLights_Pixel( 0, u32CubeLedColor[ 0]);
        u32CubeLedColor[ 5] = u32CubeLedColor[ 6];  StripLights_Pixel( 5, u32CubeLedColor[ 5]);
        u32CubeLedColor[ 6] = u32CubeLedColor[ 7];  StripLights_Pixel( 6, u32CubeLedColor[ 6]);
        u32CubeLedColor[ 7] = u32CubeLedColor[ 8];  StripLights_Pixel( 7, u32CubeLedColor[ 7]);
        u32CubeLedColor[ 8] = u32temp;  StripLights_Pixel( 8, u32CubeLedColor[ 8]);
    }
}

void CubeMove_10_to_11(void)
{
    uint32_t u32temp;
    u32temp = u32CubeLedColor[11];
    u32CubeLedColor[11] = u32CubeLedColor[10];  StripLights_Pixel(11, u32CubeLedColor[11]);
    u32CubeLedColor[10] = u32CubeLedColor[ 9];  StripLights_Pixel(10, u32CubeLedColor[10]);
    u32CubeLedColor[ 9] = u32CubeLedColor[53];  StripLights_Pixel( 9, u32CubeLedColor[ 9]);
    u32CubeLedColor[53] = u32CubeLedColor[48];  StripLights_Pixel(53, u32CubeLedColor[53]);
    u32CubeLedColor[48] = u32CubeLedColor[47];  StripLights_Pixel(48, u32CubeLedColor[48]);
    u32CubeLedColor[47] = u32CubeLedColor[42];  StripLights_Pixel(47, u32CubeLedColor[47]);
    u32CubeLedColor[42] = u32CubeLedColor[43];  StripLights_Pixel(42, u32CubeLedColor[42]);
    u32CubeLedColor[43] = u32CubeLedColor[44];  StripLights_Pixel(43, u32CubeLedColor[43]);
    u32CubeLedColor[44] = u32CubeLedColor[26];  StripLights_Pixel(44, u32CubeLedColor[44]);
    u32CubeLedColor[26] = u32CubeLedColor[21];  StripLights_Pixel(26, u32CubeLedColor[26]);
    u32CubeLedColor[21] = u32CubeLedColor[20];  StripLights_Pixel(21, u32CubeLedColor[21]);
    u32CubeLedColor[20] = u32temp;              StripLights_Pixel(20, u32CubeLedColor[20]);

    if ((u32CubeMoveSteps!=2) && (u32CubeMoveSteps!=5))
    {    
        //Aussenwand
        u32temp = u32CubeLedColor[ 2];
        u32CubeLedColor[ 2] = u32CubeLedColor[ 3];  StripLights_Pixel( 2, u32CubeLedColor[ 2]);
        u32CubeLedColor[ 3] = u32CubeLedColor[ 8];  StripLights_Pixel( 3, u32CubeLedColor[ 3]);
        u32CubeLedColor[ 8] = u32CubeLedColor[ 7];  StripLights_Pixel( 8, u32CubeLedColor[ 8]);
        u32CubeLedColor[ 7] = u32CubeLedColor[ 6];  StripLights_Pixel( 7, u32CubeLedColor[ 7]);
        u32CubeLedColor[ 6] = u32CubeLedColor[ 5];  StripLights_Pixel( 6, u32CubeLedColor[ 6]);
        u32CubeLedColor[ 5] = u32CubeLedColor[ 0];  StripLights_Pixel( 5, u32CubeLedColor[ 5]);
        u32CubeLedColor[ 0] = u32CubeLedColor[ 1];  StripLights_Pixel( 0, u32CubeLedColor[ 0]);
        u32CubeLedColor[ 1] = u32temp;  StripLights_Pixel( 1, u32CubeLedColor[ 1]);
    }
}

void CubeMove_12_to_13(void)
{
    uint32_t u32temp;
    u32temp = u32CubeLedColor[13];
    u32CubeLedColor[13] = u32CubeLedColor[12];  StripLights_Pixel(13, u32CubeLedColor[13]);
    u32CubeLedColor[12] = u32CubeLedColor[19];  StripLights_Pixel(12, u32CubeLedColor[12]);
    u32CubeLedColor[19] = u32CubeLedColor[22];  StripLights_Pixel(19, u32CubeLedColor[19]);
    u32CubeLedColor[22] = u32CubeLedColor[25];  StripLights_Pixel(22, u32CubeLedColor[22]);
    u32CubeLedColor[25] = u32CubeLedColor[39];  StripLights_Pixel(25, u32CubeLedColor[25]);
    u32CubeLedColor[39] = u32CubeLedColor[40];  StripLights_Pixel(39, u32CubeLedColor[39]);
    u32CubeLedColor[40] = u32CubeLedColor[41];  StripLights_Pixel(40, u32CubeLedColor[40]);
    u32CubeLedColor[41] = u32CubeLedColor[46];  StripLights_Pixel(41, u32CubeLedColor[41]);
    u32CubeLedColor[46] = u32CubeLedColor[49];  StripLights_Pixel(46, u32CubeLedColor[46]);
    u32CubeLedColor[49] = u32CubeLedColor[52];  StripLights_Pixel(49, u32CubeLedColor[49]);
    u32CubeLedColor[52] = u32CubeLedColor[14];  StripLights_Pixel(52, u32CubeLedColor[52]);
    u32CubeLedColor[14] = u32temp;              StripLights_Pixel(14, u32CubeLedColor[14]);
}

void CubeMove_13_to_12(void)
{
    uint32_t u32temp;
    u32temp = u32CubeLedColor[12];
    u32CubeLedColor[12] = u32CubeLedColor[13];  StripLights_Pixel(12, u32CubeLedColor[12]);
    u32CubeLedColor[13] = u32CubeLedColor[14];  StripLights_Pixel(13, u32CubeLedColor[13]);
    u32CubeLedColor[14] = u32CubeLedColor[52];  StripLights_Pixel(14, u32CubeLedColor[14]);
    u32CubeLedColor[52] = u32CubeLedColor[49];  StripLights_Pixel(52, u32CubeLedColor[52]);
    u32CubeLedColor[49] = u32CubeLedColor[46];  StripLights_Pixel(49, u32CubeLedColor[49]);
    u32CubeLedColor[46] = u32CubeLedColor[41];  StripLights_Pixel(46, u32CubeLedColor[46]);
    u32CubeLedColor[41] = u32CubeLedColor[40];  StripLights_Pixel(41, u32CubeLedColor[41]);
    u32CubeLedColor[40] = u32CubeLedColor[39];  StripLights_Pixel(40, u32CubeLedColor[40]);
    u32CubeLedColor[39] = u32CubeLedColor[25];  StripLights_Pixel(39, u32CubeLedColor[39]);
    u32CubeLedColor[25] = u32CubeLedColor[22];  StripLights_Pixel(25, u32CubeLedColor[25]);
    u32CubeLedColor[22] = u32CubeLedColor[19];  StripLights_Pixel(22, u32CubeLedColor[22]);
    u32CubeLedColor[19] = u32temp;              StripLights_Pixel(19, u32CubeLedColor[19]);
}

void CubeMove_17_to_16(void)
{
    uint32_t u32temp;
    u32temp = u32CubeLedColor[16];
    u32CubeLedColor[16] = u32CubeLedColor[17];  StripLights_Pixel(16, u32CubeLedColor[16]);
    u32CubeLedColor[17] = u32CubeLedColor[18];  StripLights_Pixel(17, u32CubeLedColor[17]);
    u32CubeLedColor[18] = u32CubeLedColor[23];  StripLights_Pixel(18, u32CubeLedColor[18]);
    u32CubeLedColor[23] = u32CubeLedColor[24];  StripLights_Pixel(23, u32CubeLedColor[23]);
    u32CubeLedColor[24] = u32CubeLedColor[38];  StripLights_Pixel(24, u32CubeLedColor[24]);
    u32CubeLedColor[38] = u32CubeLedColor[37];  StripLights_Pixel(38, u32CubeLedColor[38]);
    u32CubeLedColor[37] = u32CubeLedColor[36];  StripLights_Pixel(37, u32CubeLedColor[37]);
    u32CubeLedColor[36] = u32CubeLedColor[45];  StripLights_Pixel(36, u32CubeLedColor[36]);
    u32CubeLedColor[45] = u32CubeLedColor[50];  StripLights_Pixel(45, u32CubeLedColor[45]);
    u32CubeLedColor[50] = u32CubeLedColor[51];  StripLights_Pixel(50, u32CubeLedColor[50]);
    u32CubeLedColor[51] = u32CubeLedColor[15];  StripLights_Pixel(51, u32CubeLedColor[51]);
    u32CubeLedColor[15] = u32temp;              StripLights_Pixel(15, u32CubeLedColor[15]);

    if ((u32CubeMoveSteps!=2) && (u32CubeMoveSteps!=5))
    {    
        //Aussenwand
        u32temp = u32CubeLedColor[32];
        u32CubeLedColor[32] = u32CubeLedColor[27];  StripLights_Pixel(32, u32CubeLedColor[32]);
        u32CubeLedColor[27] = u32CubeLedColor[28];  StripLights_Pixel(27, u32CubeLedColor[27]);
        u32CubeLedColor[28] = u32CubeLedColor[29];  StripLights_Pixel(28, u32CubeLedColor[28]);
        u32CubeLedColor[29] = u32CubeLedColor[30];  StripLights_Pixel(29, u32CubeLedColor[29]);
        u32CubeLedColor[30] = u32CubeLedColor[35];  StripLights_Pixel(30, u32CubeLedColor[30]);
        u32CubeLedColor[35] = u32CubeLedColor[34];  StripLights_Pixel(35, u32CubeLedColor[35]);
        u32CubeLedColor[34] = u32CubeLedColor[33];  StripLights_Pixel(34, u32CubeLedColor[34]);
        u32CubeLedColor[33] = u32temp;  StripLights_Pixel(33, u32CubeLedColor[33]);
    }
}

void CubeMove_16_to_17(void)
{
    uint32_t u32temp;
    u32temp = u32CubeLedColor[17];
    u32CubeLedColor[17] = u32CubeLedColor[16];  StripLights_Pixel(17, u32CubeLedColor[17]);
    u32CubeLedColor[16] = u32CubeLedColor[15];  StripLights_Pixel(16, u32CubeLedColor[16]);
    u32CubeLedColor[15] = u32CubeLedColor[51];  StripLights_Pixel(15, u32CubeLedColor[15]);
    u32CubeLedColor[51] = u32CubeLedColor[50];  StripLights_Pixel(51, u32CubeLedColor[51]);
    u32CubeLedColor[50] = u32CubeLedColor[45];  StripLights_Pixel(50, u32CubeLedColor[50]);
    u32CubeLedColor[45] = u32CubeLedColor[36];  StripLights_Pixel(45, u32CubeLedColor[45]);
    u32CubeLedColor[36] = u32CubeLedColor[37];  StripLights_Pixel(36, u32CubeLedColor[36]);
    u32CubeLedColor[37] = u32CubeLedColor[38];  StripLights_Pixel(37, u32CubeLedColor[37]);
    u32CubeLedColor[38] = u32CubeLedColor[24];  StripLights_Pixel(38, u32CubeLedColor[38]);
    u32CubeLedColor[24] = u32CubeLedColor[23];  StripLights_Pixel(24, u32CubeLedColor[24]);
    u32CubeLedColor[23] = u32CubeLedColor[18];  StripLights_Pixel(23, u32CubeLedColor[23]);
    u32CubeLedColor[18] = u32temp;              StripLights_Pixel(18, u32CubeLedColor[18]);

    if ((u32CubeMoveSteps!=2) && (u32CubeMoveSteps!=5))
    {    
        //Aussenwand
        u32temp = u32CubeLedColor[27];
        u32CubeLedColor[27] = u32CubeLedColor[32];  StripLights_Pixel(27, u32CubeLedColor[27]);
        u32CubeLedColor[32] = u32CubeLedColor[33];  StripLights_Pixel(32, u32CubeLedColor[32]);
        u32CubeLedColor[33] = u32CubeLedColor[34];  StripLights_Pixel(33, u32CubeLedColor[33]);
        u32CubeLedColor[34] = u32CubeLedColor[35];  StripLights_Pixel(34, u32CubeLedColor[34]);
        u32CubeLedColor[35] = u32CubeLedColor[30];  StripLights_Pixel(35, u32CubeLedColor[35]);
        u32CubeLedColor[30] = u32CubeLedColor[29];  StripLights_Pixel(30, u32CubeLedColor[30]);
        u32CubeLedColor[29] = u32CubeLedColor[28];  StripLights_Pixel(29, u32CubeLedColor[29]);
        u32CubeLedColor[28] = u32temp;  StripLights_Pixel(28, u32CubeLedColor[28]);
    }
}

#endif // StripLights

//
// SYSTICK
//
#define SYSTICKS    2400000
uint32_t u32SysTickCnt;
CY_ISR(mySystick_ISR)
{ 
    if (++u32SysTickCnt > 10)
    {
        //LED_Write(!LED_Read());  
        u32SysTickCnt = 0;
    }
    #ifdef CY_SCB_StripLights_H
    //StripLights_Trigger();
    #endif
}

uint32_t CheckCubeSolved()
{
    uint32_t u32i;
    uint32_t u32Solved;                // '1' when solved
    
     // Check for solving

    u32Solved = 1;
    for (u32i=1; (u32i < 9) && u32Solved; u32i++)
    {
        if (u32CubeLedColor[0] != u32CubeLedColor[u32i])
        {
            u32Solved = 0;   
        }
    }
    for (u32i=10; (u32i < 18) && u32Solved; u32i++)
    {
        if (u32CubeLedColor[9] != u32CubeLedColor[u32i])
        {
            u32Solved = 0;   
        }
    }
    for (u32i=19; (u32i < 27) && u32Solved; u32i++)
    {
        if (u32CubeLedColor[18] != u32CubeLedColor[u32i])
        {
            u32Solved = 0;   
        }
    }
    for (u32i=28; (u32i < 36) && u32Solved; u32i++)
    {
        if (u32CubeLedColor[27] != u32CubeLedColor[u32i])
        {
            u32Solved = 0;   
        }
    }
    for (u32i=37; (u32i < 45) && u32Solved; u32i++)
    {
        if (u32CubeLedColor[36] != u32CubeLedColor[u32i])
        {
            u32Solved = 0;   
        }
    }

    return(u32Solved);
}

//
// Timer25ms
//

CY_ISR(isr_Timer25ms)
{    
    Timer25ms_ClearInterrupt(Timer25ms_INTR_MASK_TC); // Clear IRQ-flag
    
    StripLights_Trigger();
    
    if (u32Timer25ms_Delay)
    {
        u32Timer25ms_Delay--;
    }
    
    if (u32Timer25ms_DelayCenter)
    {
        u32Timer25ms_DelayCenter--;
    }
    
    if (u32Timer25ms_Delay00)
    {
        u32Timer25ms_Delay00--;
        if (0 == u32Timer25ms_Delay00)
        {
            enTouchState00 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r00:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay01)
    {
        u32Timer25ms_Delay01--;
        if (0 == u32Timer25ms_Delay01)
        {
            enTouchState01 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r01:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay02)
    {
        u32Timer25ms_Delay02--;
        if (0 == u32Timer25ms_Delay02)
        {
            enTouchState02 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r02:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay03)
    {
        u32Timer25ms_Delay03--;
        if (0 == u32Timer25ms_Delay03)
        {
            enTouchState03 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r03:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay05)
    {
        u32Timer25ms_Delay05--;
        if (0 == u32Timer25ms_Delay05)
        {
            enTouchState05 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r05:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay06)
    {
        u32Timer25ms_Delay06--;
        if (0 == u32Timer25ms_Delay06)
        {
            enTouchState06 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r06:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay07)
    {
        u32Timer25ms_Delay07--;
        if (0 == u32Timer25ms_Delay07)
        {
            enTouchState07 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r07:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay08)
    {
        u32Timer25ms_Delay08--;
        if (0 == u32Timer25ms_Delay08)
        {
            enTouchState08 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r08:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay09)
    {
        u32Timer25ms_Delay09--;
        if (0 == u32Timer25ms_Delay09)
        {
            enTouchState09 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r09:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay10)
    {
        u32Timer25ms_Delay10--;
        if (0 == u32Timer25ms_Delay10)
        {
            enTouchState10 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r10:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay11)
    {
        u32Timer25ms_Delay11--;
        if (0 == u32Timer25ms_Delay11)
        {
            enTouchState11 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r11:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay12)
    {
        u32Timer25ms_Delay12--;
        if (0 == u32Timer25ms_Delay12)
        {
            enTouchState12 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r12:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay14)
    {
        u32Timer25ms_Delay14--;
        if (0 == u32Timer25ms_Delay14)
        {
            enTouchState14 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r14:timeout"); 
            #endif
        }
    }
    
    	if (u32Timer25ms_Delay15)
    {
        u32Timer25ms_Delay15--;
        if (0 == u32Timer25ms_Delay15)
        {
            enTouchState15 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r15:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay16)
    {
        u32Timer25ms_Delay16--;
        if (0 == u32Timer25ms_Delay16)
        {
            enTouchState16 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r16:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay17)
    {
        u32Timer25ms_Delay17--;
        if (0 == u32Timer25ms_Delay17)
        {
            enTouchState17 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r17:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay18)
    {
        u32Timer25ms_Delay18--;
        if (0 == u32Timer25ms_Delay18)
        {
            enTouchState18 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r18:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay19)
    {
        u32Timer25ms_Delay19--;
        if (0 == u32Timer25ms_Delay19)
        {
            enTouchState19 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r19:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay20)
    {
        u32Timer25ms_Delay20--;
        if (0 == u32Timer25ms_Delay20)
        {
            enTouchState20 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r20:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay21)
    {
        u32Timer25ms_Delay21--;
        if (0 == u32Timer25ms_Delay21)
        {
            enTouchState21 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r21:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay23)
    {
        u32Timer25ms_Delay23--;
        if (0 == u32Timer25ms_Delay23)
        {
            enTouchState23 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r23:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay24)
    {
        u32Timer25ms_Delay24--;
        if (0 == u32Timer25ms_Delay24)
        {
            enTouchState24 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r24:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay25)
    {
        u32Timer25ms_Delay25--;
        if (0 == u32Timer25ms_Delay25)
        {
            enTouchState25 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r25:timeout"); 
            #endif
        }
    }
		
	if (u32Timer25ms_Delay26)
    {
        u32Timer25ms_Delay26--;
        if (0 == u32Timer25ms_Delay26)
        {
            enTouchState26 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r26:timeout"); 
            #endif
        }
    }
	
	if (u32Timer25ms_Delay27)
    {
        u32Timer25ms_Delay27--;
        if (0 == u32Timer25ms_Delay27)
        {
            enTouchState27 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r27:timeout"); 
            #endif
        }
    }
	
	if (u32Timer25ms_Delay28)
    {
        u32Timer25ms_Delay28--;
        if (0 == u32Timer25ms_Delay28)
        {
            enTouchState28 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r28:timeout"); 
            #endif
        }
    }
	
	if (u32Timer25ms_Delay29)
    {
        u32Timer25ms_Delay29--;
        if (0 == u32Timer25ms_Delay29)
        {
            enTouchState29 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r29:timeout"); 
            #endif
        }
    }
	
	if (u32Timer25ms_Delay30)
    {
        u32Timer25ms_Delay30--;
        if (0 == u32Timer25ms_Delay30)
        {
            enTouchState30 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r30:timeout"); 
            #endif
        }
    }
	   
    if (u32Timer25ms_Delay32)
    {
        u32Timer25ms_Delay32--;
        if (0 == u32Timer25ms_Delay32)
        {
            enTouchState32 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r32:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay33)
    {
        u32Timer25ms_Delay33--;
        if (0 == u32Timer25ms_Delay33)
        {
            enTouchState33 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r33:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay34)
    {
        u32Timer25ms_Delay34--;
        if (0 == u32Timer25ms_Delay34)
        {
            enTouchState34 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r34:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay35)
    {
        u32Timer25ms_Delay35--;
        if (0 == u32Timer25ms_Delay35)
        {
            enTouchState35 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r35:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay36)
    {
        u32Timer25ms_Delay36--;
        if (0 == u32Timer25ms_Delay36)
        {
            enTouchState36 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r36:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay37)
    {
        u32Timer25ms_Delay37--;
        if (0 == u32Timer25ms_Delay37)
        {
            enTouchState37 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r37:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay38)
    {
        u32Timer25ms_Delay38--;
        if (0 == u32Timer25ms_Delay38)
        {
            enTouchState38 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r38:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay39)
    {
        u32Timer25ms_Delay39--;
        if (0 == u32Timer25ms_Delay39)
        {
            enTouchState39 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r39:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay41)
    {
        u32Timer25ms_Delay41--;
        if (0 == u32Timer25ms_Delay41)
        {
            enTouchState41 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r41:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay42)
    {
        u32Timer25ms_Delay42--;
        if (0 == u32Timer25ms_Delay42)
        {
            enTouchState42 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r42:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay43)
    {
        u32Timer25ms_Delay43--;
        if (0 == u32Timer25ms_Delay43)
        {
            enTouchState43 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r43:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay44)
    {
        u32Timer25ms_Delay44--;
        if (0 == u32Timer25ms_Delay44)
        {
            enTouchState44 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r44:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay45)
    {
        u32Timer25ms_Delay45--;
        if (0 == u32Timer25ms_Delay45)
        {
            enTouchState45 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r45:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay46)
    {
        u32Timer25ms_Delay46--;
        if (0 == u32Timer25ms_Delay46)
        {
            enTouchState46 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r46:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay47)
    {
        u32Timer25ms_Delay47--;
        if (0 == u32Timer25ms_Delay47)
        {
            enTouchState47 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r47:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay48)
    {
        u32Timer25ms_Delay48--;
        if (0 == u32Timer25ms_Delay48)
        {
            enTouchState48 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r48:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay50)
    {
        u32Timer25ms_Delay50--;
        if (0 == u32Timer25ms_Delay50)
        {
            enTouchState50 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r50:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay51)
    {
        u32Timer25ms_Delay51--;
        if (0 == u32Timer25ms_Delay51)
        {
            enTouchState51 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r51:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay52)
    {
        u32Timer25ms_Delay52--;
        if (0 == u32Timer25ms_Delay52)
        {
            enTouchState52 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r52:timeout"); 
            #endif
        }
    }
    
    if (u32Timer25ms_Delay53)
    {
        u32Timer25ms_Delay53--;
        if (0 == u32Timer25ms_Delay53)
        {
            enTouchState53 = TOUCH_IDLE;
            #ifndef SoftwareUART__DISABLED 
                UART_PutString("\r53:timeout"); 
            #endif
        }
    }
    
    
    
    if (u32Timer25ms_DelayTurn)
    {
        u32Timer25ms_DelayTurn--;
    }
    
    
    
    //
    // Get Touch status
    //
    
    // Cube side 0
    if(CapSense_NOT_BUSY == CapSense_IsBusy())
    {   
        CapSense_ProcessAllWidgets(); // Process all widgets
        //CapSense_RunTuner();          // Update data for CapSense tuner
        
        u32TouchFlag = 0;
        if (CapSense_IsWidgetActive (CapSense_T1_WDGT_ID)) { u32TouchFlag = u32TouchFlag | 0x0001; }
        if (CapSense_IsWidgetActive (CapSense_T2_WDGT_ID)) { u32TouchFlag = u32TouchFlag | 0x0002; }
        if (CapSense_IsWidgetActive (CapSense_T3_WDGT_ID)) { u32TouchFlag = u32TouchFlag | 0x0004; }            
        if (CapSense_IsWidgetActive (CapSense_T4_WDGT_ID)) { u32TouchFlag = u32TouchFlag | 0x0008; }
        if (CapSense_IsWidgetActive (CapSense_T5_WDGT_ID)) { u32TouchFlag = u32TouchFlag | 0x0010; }
        if (CapSense_IsWidgetActive (CapSense_T6_WDGT_ID)) { u32TouchFlag = u32TouchFlag | 0x0020; }
        if (CapSense_IsWidgetActive (CapSense_T7_WDGT_ID)) { u32TouchFlag = u32TouchFlag | 0x0040; }
        if (CapSense_IsWidgetActive (CapSense_T8_WDGT_ID)) { u32TouchFlag = u32TouchFlag | 0x0080; }
        if (CapSense_IsWidgetActive (CapSense_T9_WDGT_ID)) { u32TouchFlag = u32TouchFlag | 0x0100; }
        
        u32aCubeTouch[0] = u32TouchFlag;
        CapSense_ScanAllWidgets(); // Start next scan
        
    } // if(CapSense_NOT_BUSY == CapSense_IsBusy())
 
    if (!u32CubeOffFlag)
    {
        // Cube side 1
        
        I2C_I2CMasterClearStatus();             // Clear I2C Master status
        I2C_I2CMasterReadBuf(0x21, (uint8_t*)&u32aCubeTouch[1], 2, I2C_I2C_MODE_COMPLETE_XFER);
        while((I2C_I2CMasterStatus() & I2C_I2C_MSTAT_RD_CMPLT) == 0u);

        // Cube side 2
        
        I2C_I2CMasterClearStatus();             // Clear I2C Master status
        I2C_I2CMasterReadBuf(0x22, (uint8_t*)&u32aCubeTouch[2], 2, I2C_I2C_MODE_COMPLETE_XFER);
        while((I2C_I2CMasterStatus() & I2C_I2C_MSTAT_RD_CMPLT) == 0u);
        
        // Cube side 3
        
        I2C_I2CMasterClearStatus();             // Clear I2C Master status
        I2C_I2CMasterReadBuf(0x23, (uint8_t*)&u32aCubeTouch[3], 2, I2C_I2C_MODE_COMPLETE_XFER);
        while((I2C_I2CMasterStatus() & I2C_I2C_MSTAT_RD_CMPLT) == 0u);
        
        // Cube side 4
        
        I2C_I2CMasterClearStatus();             // Clear I2C Master status
        I2C_I2CMasterReadBuf(0x24, (uint8_t*)&u32aCubeTouch[4], 2, I2C_I2C_MODE_COMPLETE_XFER);
        while((I2C_I2CMasterStatus() & I2C_I2C_MSTAT_RD_CMPLT) == 0u);
        
        // Cube side 5
        
        I2C_I2CMasterClearStatus();             // Clear I2C Master status
        I2C_I2CMasterReadBuf(0x25, (uint8_t*)&u32aCubeTouch[5], 2, I2C_I2C_MODE_COMPLETE_XFER);
        while((I2C_I2CMasterStatus() & I2C_I2C_MSTAT_RD_CMPLT) == 0u);
    }
    else
    {
        u32aCubeTouch[1] = 0;
        u32aCubeTouch[2] = 0;
        u32aCubeTouch[3] = 0;
        u32aCubeTouch[4] = 0;
        u32aCubeTouch[5] = 0;   
    }
    
    // In case the cube stands on a table then deactivate this side
    
    if (0x1FF == u32aCubeTouch[0]) { u32aCubeTouch[0] = 0; }
    if (0x1FF == u32aCubeTouch[1]) { u32aCubeTouch[1] = 0; }
    if (0x1FF == u32aCubeTouch[2]) { u32aCubeTouch[2] = 0; }
    if (0x1FF == u32aCubeTouch[3]) { u32aCubeTouch[3] = 0; }
    if (0x1FF == u32aCubeTouch[4]) { u32aCubeTouch[4] = 0; }
    if (0x1FF == u32aCubeTouch[5]) { u32aCubeTouch[5] = 0; }
    
    #ifndef SoftwareUART__DISABLED
     
        if (u32aCubeTouchOld[5] != u32aCubeTouch[5])
        {
            sprintf(aPrintfBuffer, "\r5:%03x 4:%03x 3:%03x 2:%03x 1:%03x 0:%03x", u32aCubeTouch[5], u32aCubeTouch[4], u32aCubeTouch[3], u32aCubeTouch[2], u32aCubeTouch[1], u32aCubeTouch[0]);
            UART_PutString(aPrintfBuffer);
            u32aCubeTouchOld[5] = u32aCubeTouch[5];
        }
        
    #endif
    
    #ifndef SoftwareUART__DISABLED
        
//        u32UntouchCnt = u32UntouchCnt + 1;
//        
//        if (u32aCubeTouchOld[0] != u32aCubeTouch[0])
//        {
//            sprintf(aPrintfBuffer, "\r0:%03x", u32aCubeTouch[0]);
//            UART_PutString(aPrintfBuffer);
//            u32aCubeTouchOld[0] = u32aCubeTouch[0];
//            u32UntouchCnt = 0;
//        }
//        else
//        {
//            if (u32UntouchCnt == 30)
//            {
//                UART_PutChar('\r');
//            }   
//        }
//        
//        if (u32aCubeTouchOld[1] != u32aCubeTouch[1])
//        {
//            sprintf(aPrintfBuffer, " 1:%03x", u32aCubeTouch[1]);
//            UART_PutString(aPrintfBuffer);
//            u32aCubeTouchOld[1] = u32aCubeTouch[1];
//        }
//        if (u32aCubeTouchOld[2] != u32aCubeTouch[2])
//        {
//            sprintf(aPrintfBuffer, " 2:%03x", u32aCubeTouch[2]);
//            UART_PutString(aPrintfBuffer);
//            u32aCubeTouchOld[2] = u32aCubeTouch[2];
//        }
//        if (u32aCubeTouchOld[3] != u32aCubeTouch[3])
//        {
//            sprintf(aPrintfBuffer, " 3:%03x", u32aCubeTouch[3]);
//            UART_PutString(aPrintfBuffer);
//            u32aCubeTouchOld[3] = u32aCubeTouch[3];
//        }
//        if (u32aCubeTouchOld[4] != u32aCubeTouch[4])
//        {
//            sprintf(aPrintfBuffer, " 4:%03x", u32aCubeTouch[4]);
//            UART_PutString(aPrintfBuffer);
//            u32aCubeTouchOld[4] = u32aCubeTouch[4];
//        }
//        if (u32aCubeTouchOld[5] != u32aCubeTouch[5])
//        {
//            sprintf(aPrintfBuffer, " 5:%03x", u32aCubeTouch[5]);
//            UART_PutString(aPrintfBuffer);
//            u32aCubeTouchOld[5] = u32aCubeTouch[5];
//        }
        
    #endif
    
    if (0 == u32CubeMoveSteps)
    {
        
    // --------------
    // Evaluate Touch
    // --------------
    
    // Center Touch
    
    switch (enTouchStateCenter)
    {
        // WAITING FOR 1st TOUCH
        
        case TOUCH_CENTER_IDLE: // waiting for first touch
        
            // 1. Touch Center?
        
            if (u32aCubeTouch[0] == 0x010)
            {
                u32TouchClickCount = 1;
                u32TouchedCenterField = 0;
            }
            if (u32aCubeTouch[1] == 0x010)
            {
                u32TouchClickCount = 1;
                u32TouchedCenterField = 1;
            }
            if (u32aCubeTouch[2] == 0x010)
            {
                u32TouchClickCount = 1;
                u32TouchedCenterField = 2;
            }
            if (u32aCubeTouch[3] == 0x010)
            {
                u32TouchClickCount = 1;
                u32TouchedCenterField = 3;
            }
            if (u32aCubeTouch[4] == 0x010)
            {
                u32TouchClickCount = 1;
                u32TouchedCenterField = 4;
            }
            if (u32aCubeTouch[5] == 0x010)
            {
                u32TouchClickCount = 1;
                u32TouchedCenterField = 5;
            }
            
            if (u32TouchClickCount)
            {
                enTouchStateCenter = TOUCH_CENTER_CLICK_ON; // center touched
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\rCenter touched"); 
                #endif
            }
            break;
            
        case TOUCH_CENTER_CLICK_ON: // wait for center touch release
            
            if ((u32aCubeTouch[u32TouchedCenterField] & 0x010) == 0)
            {
                u32Timer25ms_DelayCenter = TOUCHTIME;
                enTouchStateCenter = TOUCH_CENTER_CLICK_OFF; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\rCenter Release"); 
                #endif
            }
            break;
                
        case TOUCH_CENTER_CLICK_OFF:
            
            if (u32aCubeTouch[u32TouchedCenterField] & 0x010)
            {
                u32TouchClickCount = u32TouchClickCount + 1; 
                enTouchStateCenter = TOUCH_CENTER_CLICK_ON; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\rCenter Touch"); 
                #endif
                
            }
            if (0 == u32Timer25ms_DelayCenter)
            { 
                enTouchStateCenter = TOUCH_CENTER_CLICK_DONE; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\rCenter Done"); 
                #endif
            }
            break;
            
        case TOUCH_CENTER_CLICK_DONE:
            
            switch (u32TouchClickCount)
            {
                case 1 : // 1x Click
                
                    #ifndef SoftwareUART__DISABLED 
                        UART_PutString("\r1x Center"); 
                    #endif
                    break;   
                    
                case 2 : // 2x Click
                    
                    enCubeModeKeep = enCubeMode; // Return current keep mode after intensty is changed
                    enCubeMode = CUBEMODE_LIGHT;
                    #ifndef SoftwareUART__DISABLED 
                        UART_PutString("\r2x Center"); 
                    #endif
                    break;
                    
                case 3 : // 3x Click -> new game (color mixer)
                    
                    enCubeMode = CUBEMODE_MIX;
                    #ifndef SoftwareUART__DISABLED 
                        UART_PutString("\r3x Center"); 
                    #endif
                    break;                
                    
                case 4 : // 4x Click
                    
                    #ifndef SoftwareUART__DISABLED 
                        UART_PutString("\r4x Center"); 
                    #endif
                    break;               
                    
                case 5 : // 5x Click -> Reset
                    
                    #ifndef SoftwareUART__DISABLED 
                        UART_PutString("\r5x Center"); 
                    #endif
                    CySoftwareReset();
                    break;
                    
                default: break;
            }

            u32TouchClickCount = 0;
            enTouchStateCenter = TOUCH_CENTER_IDLE;
            break;
            
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchStateCenter [%d] ***", enTouchStateCenter);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
            
    } // switch (enTouchStateCenter)
    
    #ifdef P0
    // ------
    // PAGE 0
    // ------
    
    // Touch 00
    
    switch (enTouchState00)
    {
        case TOUCH_IDLE: // Start with 00
        
            if (    
                       (((u32aCubeTouch[5] & 0x000) == 0x000) && ((u32aCubeTouch[4] & 0x10C) == 0x000) && ((u32aCubeTouch[3] & 0x007) == 0x000) && ((u32aCubeTouch[2] & 0x1FF) == 0x000) && ((u32aCubeTouch[1] & 0x10C) == 0x000) && ((u32aCubeTouch[0] & 0x007) == 0x001)) // Start with 00
                    || (((u32aCubeTouch[5] & 0x007) == 0x000) && ((u32aCubeTouch[4] & 0x1FF) == 0x000) && ((u32aCubeTouch[3] & 0x10C) == 0x000) && ((u32aCubeTouch[2] & 0x1C0) == 0x000) && ((u32aCubeTouch[1] & 0x000) == 0x000) && ((u32aCubeTouch[0] & 0x061) == 0x001)) // Start with 00
                )
            {
                u32Timer25ms_Delay00 = TOUCHTIME;
                enTouchState00 = TOUCH_001;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r00 (1st)"); 
                #endif
            }
            break;

        case TOUCH_001: // Waiting for 2nd touch -> 01 or 05
        
            if ( (0 == (u32aCubeTouch[0] & TOUCH0)) && (u32aCubeTouch[0] & TOUCH1) )
            {
                enTouchState00 = TOUCH_001_002; 
                u32Timer25ms_Delay00 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r01 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[0] & TOUCH0)) && (u32aCubeTouch[0] & TOUCH5) )
            {
                enTouchState00 = TOUCH_001_020; 
                u32Timer25ms_Delay00 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r05 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_001_002: // Waiting for 3rd touch -> 02

            if (u32aCubeTouch[0] & TOUCH2)
            {
                enTouchState00 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_00_01; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r02 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_001_020: // Waiting for 3rd touch -> 06

            if (u32aCubeTouch[0] & TOUCH6)
            {
                enTouchState00 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_00_05; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r06 (3rd)"); 
                #endif
            }
            break;
             
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState00 [%d] ***", enTouchState00);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState00)
  
    // Touch 01
    
    switch (enTouchState01)
    {
        case TOUCH_IDLE: // Start with 01
        
            if (    
                    (((u32aCubeTouch[5] & 0x038) == 0x000) && ((u32aCubeTouch[4] & 0x000) == 0x000) && ((u32aCubeTouch[3] & 0x092) == 0x000) && ((u32aCubeTouch[2] & 0x038) == 0x000) && ((u32aCubeTouch[1] & 0x000) == 0x000) && ((u32aCubeTouch[0] & 0x092) == 0x002)) // Start with 01
                )
            {
                u32Timer25ms_Delay01 = TOUCHTIME;
                enTouchState01 = TOUCH_002;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r01 (1st)"); 
                #endif
            }
            break;

        case TOUCH_002: // Waiting for 2nd touch -> 04

            if ( (0 == (u32aCubeTouch[0] & TOUCH1)) && (u32aCubeTouch[0] & TOUCH4) )
            {
                enTouchState01 = TOUCH_002_010; 
                u32Timer25ms_Delay01 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r04 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_002_010: // Waiting for 3rd touch -> 07

            if (u32aCubeTouch[0] & TOUCH7)
            {
                enTouchState01 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_01_04; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r07 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState01 [%d] ***", enTouchState01);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState01)

    // Touch 02
    
    switch (enTouchState02)
    {
        case TOUCH_IDLE: // Start with 02
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x1C0) == 0x000) && ((u32aCubeTouch[4] & 0x000) == 0x000) && ((u32aCubeTouch[3] & 0x061) == 0x000) && ((u32aCubeTouch[2] & 0x007) == 0x000) && ((u32aCubeTouch[1] & 0x1FF) == 0x000) && ((u32aCubeTouch[0] & 0x10C) == 0x004)) // Start with 02
                    || ( ((u32aCubeTouch[5] & 0x000) == 0x000) && ((u32aCubeTouch[4] & 0x10C) == 0x000) && ((u32aCubeTouch[3] & 0x007) == 0x000) && ((u32aCubeTouch[2] & 0x1FF) == 0x000) && ((u32aCubeTouch[1] & 0x10C) == 0x000) && ((u32aCubeTouch[0] & 0x007) == 0x004)) // Start with 02
                )
            {
                u32Timer25ms_Delay02 = TOUCHTIME;
                enTouchState02 = TOUCH_004;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r02 (1st)"); 
                #endif
            }
            break;

        case TOUCH_004: // Waiting for 2nd touch
        
            if ( (0 == (u32aCubeTouch[0] & TOUCH2)) && (u32aCubeTouch[0] & TOUCH1) )
            {
                enTouchState02 = TOUCH_004_002; 
                u32Timer25ms_Delay02 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r01 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[0] & TOUCH2)) && (u32aCubeTouch[0] & TOUCH3) )
            {
                enTouchState02 = TOUCH_004_008; 
                u32Timer25ms_Delay02 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r03 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_004_002: // Waiting for 3rd touch -> 00

            if (u32aCubeTouch[0] & TOUCH0)
            {
                enTouchState02 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_01_00; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r00 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_004_008: // Waiting for 3rd touch -> 08

            if (u32aCubeTouch[0] & TOUCH8)
            {
                enTouchState02 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_02_03; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r08 (3rd)"); 
                #endif
            }
            break;
        
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState02 [%d] ***", enTouchState02);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState02)
     
    // Touch 03
    
    switch (enTouchState03)
    {
        case TOUCH_IDLE: // // Start with 03
        
            if (    
                (((u32aCubeTouch[5] & 0x000) == 0x000) && ((u32aCubeTouch[4] & 0x092) == 0x000) && ((u32aCubeTouch[3] & 0x038) == 0x000) && ((u32aCubeTouch[2] & 0x000) == 0x000) && ((u32aCubeTouch[1] & 0x092) == 0x000) && ((u32aCubeTouch[0] & 0x038) == 0x008)) // Start with 03
                )
            {
                u32Timer25ms_Delay03 = TOUCHTIME;
                enTouchState03 = TOUCH_008;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r03 (1st)"); 
                #endif
            }
            break;

        case TOUCH_008: // Waiting for 2nd touch -> 04

            if ( (0 == (u32aCubeTouch[0] & TOUCH3)) && (u32aCubeTouch[0] & TOUCH4) )
            {
                enTouchState03 = TOUCH_008_010; 
                u32Timer25ms_Delay03 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r04 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_008_010: // Waiting for 3rd touch -> 05

            if (u32aCubeTouch[0] & TOUCH5)
            {
                enTouchState03 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_04_05; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r05 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState03 [%d] ***", enTouchState03);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState03)
    
    // Touch 05
    
    switch (enTouchState05)
    {
        case TOUCH_IDLE: // Start with 05
        
            if (    
                ( ((u32aCubeTouch[5] & 0x000) == 0x000) && ((u32aCubeTouch[4] & 0x092) == 0x000) && ((u32aCubeTouch[3] & 0x038) == 0x000) && ((u32aCubeTouch[2] & 0x000) == 0x000) && ((u32aCubeTouch[1] & 0x092) == 0x000) && ((u32aCubeTouch[0] & 0x038) == 0x020)) // Start with 05
                )
            {
                u32Timer25ms_Delay05 = TOUCHTIME;
                enTouchState05 = TOUCH_020;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r05 (1st)"); 
                #endif
            }
            break;

        case TOUCH_020: // Waiting for 2nd touch -> 04

            if ( (0 == (u32aCubeTouch[0] & TOUCH5)) && (u32aCubeTouch[0] & TOUCH4) )
            {
                enTouchState05 = TOUCH_020_010; 
                u32Timer25ms_Delay05 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r04 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_020_010: // Waiting for 3rd touch -> 03

            if (u32aCubeTouch[0] & TOUCH3)
            {
                enTouchState05 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_05_04; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r03 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState05 [%d] ***", enTouchState05);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState05)
    
    // Touch 06
    
    switch (enTouchState06)
    {
        case TOUCH_IDLE: // Start with 06
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x1FF) == 0x000) && ((u32aCubeTouch[4] & 0x061) == 0x000) && ((u32aCubeTouch[3] & 0x1C0) == 0x000) && ((u32aCubeTouch[2] & 0x000) == 0x000) && ((u32aCubeTouch[1] & 0x061) == 0x000) && ((u32aCubeTouch[0] & 0x1C0) == 0x040)) // Start with 06
                    || ( ((u32aCubeTouch[5] & 0x007) == 0x000) && ((u32aCubeTouch[4] & 0x1FF) == 0x000) && ((u32aCubeTouch[3] & 0x10C) == 0x000) && ((u32aCubeTouch[2] & 0x1C0) == 0x000) && ((u32aCubeTouch[1] & 0x000) == 0x000) && ((u32aCubeTouch[0] & 0x061) == 0x040)) // Start with 06
                )
            {
                u32Timer25ms_Delay06 = TOUCHTIME;
                enTouchState06 = TOUCH_040;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r06 (1st)"); 
                #endif
            }
            break;

        case TOUCH_040: // Waiting for 2nd touch -> 05 or 07
        
            if ( (0 == (u32aCubeTouch[0] & TOUCH6)) && (u32aCubeTouch[0] & TOUCH5) )
            {
                enTouchState06 = TOUCH_040_020; 
                u32Timer25ms_Delay06 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r05 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[0] & TOUCH6)) && (u32aCubeTouch[0] & TOUCH7) )
            {
                enTouchState06 = TOUCH_040_080; 
                u32Timer25ms_Delay06 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r07 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_040_020: // Waiting for 3rd touch -> 00

            if (u32aCubeTouch[0] & TOUCH0)
            {
                enTouchState06 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_05_00; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r00 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_040_080: // Waiting for 3rd touch -> 08

            if (u32aCubeTouch[0] & TOUCH8)
            {
                enTouchState06 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_06_07; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r08 (3rd)"); 
                #endif
            }
            break;
             
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState06 [%d] ***", enTouchState06);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState06)
  
    // Touch 07
    
    switch (enTouchState07)
    {
        case TOUCH_IDLE: // Start with 07
        
            if (    
                    ( ((u32aCubeTouch[5] & 0x038) == 0x000) && ((u32aCubeTouch[4] & 0x000) == 0x000) && ((u32aCubeTouch[3] & 0x092) == 0x000) && ((u32aCubeTouch[2] & 0x038) == 0x000) && ((u32aCubeTouch[1] & 0x000) == 0x000) && ((u32aCubeTouch[0] & 0x092) == 0x080)) // Start with 07
                )
            {
                u32Timer25ms_Delay07 = TOUCHTIME;
                enTouchState07 = TOUCH_080;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r07 (1st)"); 
                #endif
            }
            break;

        case TOUCH_080: // Waiting for 2nd touch -> 04

            if ( (0 == (u32aCubeTouch[0] & TOUCH7)) && (u32aCubeTouch[0] & TOUCH4) )
            {
                enTouchState07 = TOUCH_080_010; 
                u32Timer25ms_Delay07 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r04 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_080_010: // Waiting for 3rd touch -> 01

            if (u32aCubeTouch[0] & TOUCH1)
            {
                enTouchState07 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_04_01; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r01 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState07 [%d] ***", enTouchState07);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState07)

    // Touch 08
    
    switch (enTouchState08)
    {
        case TOUCH_IDLE: // Start with 08
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x1FF) == 0x000) && ((u32aCubeTouch[4] & 0x061) == 0x000) && ((u32aCubeTouch[3] & 0x1C0) == 0x000) && ((u32aCubeTouch[2] & 0x000) == 0x000) && ((u32aCubeTouch[1] & 0x061) == 0x000) && ((u32aCubeTouch[0] & 0x1C0) == 0x100)) // Start with 08
                    || ( ((u32aCubeTouch[5] & 0x1C0) == 0x000) && ((u32aCubeTouch[4] & 0x000) == 0x000) && ((u32aCubeTouch[3] & 0x061) == 0x000) && ((u32aCubeTouch[2] & 0x007) == 0x000) && ((u32aCubeTouch[1] & 0x1FF) == 0x000) && ((u32aCubeTouch[0] & 0x10C) == 0x100)) // Start with 08                )
                )
            {
                u32Timer25ms_Delay08 = TOUCHTIME;
                enTouchState08 = TOUCH_100;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r08 (1st)"); 
                #endif
            }
            break;

        case TOUCH_100: // Waiting for 2nd touch
        
            if ( (0 == (u32aCubeTouch[0] & TOUCH8)) && (u32aCubeTouch[0] & TOUCH3) )
            {
                enTouchState08 = TOUCH_100_008; 
                u32Timer25ms_Delay08 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r03 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[0] & TOUCH8)) && (u32aCubeTouch[0] & TOUCH7) )
            {
                enTouchState08 = TOUCH_100_080; 
                u32Timer25ms_Delay08 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r07 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_100_008: // Waiting for 3rd touch -> 02

            if (u32aCubeTouch[0] & TOUCH2)
            {
                enTouchState08 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_03_02; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r02 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_100_080: // Waiting for 3rd touch -> 06

            if (u32aCubeTouch[0] & TOUCH6)
            {
                enTouchState08 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_07_06; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r06 (3rd)"); 
                #endif
            }
            break;
        
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState08 [%d] ***", enTouchState00);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState08)
    #endif
    
    #ifdef P1
    // ------
    // PAGE 1
    // ------
    
    // Touch 09
    
    switch (enTouchState09)
    {
        case TOUCH_IDLE: // Start with 09
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x10C) == 0x000) && ((u32aCubeTouch[4] & 0x1C0) == 0x000) && ((u32aCubeTouch[3] & 0x000) == 0x000) && ((u32aCubeTouch[2] & 0x10C) == 0x000) && ((u32aCubeTouch[1] & 0x007) == 0x001) && ((u32aCubeTouch[0] & 0x1FF) == 0x000)) // Start with 09
                    || ( ((u32aCubeTouch[5] & 0x1FF) == 0x000) && ((u32aCubeTouch[4] & 0x061) == 0x000) && ((u32aCubeTouch[3] & 0x1C0) == 0x000) && ((u32aCubeTouch[2] & 0x000) == 0x000) && ((u32aCubeTouch[1] & 0x061) == 0x001) && ((u32aCubeTouch[0] & 0x1C0) == 0x000)) // Start with 09
                )
            {
                u32Timer25ms_Delay09 = TOUCHTIME;
                enTouchState09 = TOUCH_001;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r09 (1st)"); 
                #endif
            }
            break;

        case TOUCH_001: // Waiting for 2nd touch -> 10 or 14
        
            if ( (0 == (u32aCubeTouch[1] & TOUCH0)) && (u32aCubeTouch[1] & TOUCH1) )
            {
                enTouchState09 = TOUCH_001_002; 
                u32Timer25ms_Delay09 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r10 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[1] & TOUCH0)) && (u32aCubeTouch[1] & TOUCH5) )
            {
                enTouchState09 = TOUCH_001_020; 
                u32Timer25ms_Delay09 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r14 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_001_002: // Waiting for 3rd touch -> 11

            if (u32aCubeTouch[1] & TOUCH2)
            {
                enTouchState09 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_10_11; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r11 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_001_020: // Waiting for 3rd touch -> 15

            if (u32aCubeTouch[1] & TOUCH6)
            {
                enTouchState09 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_06_07; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r15 (3rd)"); 
                #endif
            }
            break;
             
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState09 [%d] ***", enTouchState09);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState09)
  
    // Touch 10
    
    switch (enTouchState10)
    {
        case TOUCH_IDLE: // Start with 10
        
            if (    
                    ( ((u32aCubeTouch[5] & 0x000) == 0x000) && ((u32aCubeTouch[4] & 0x092) == 0x000) && ((u32aCubeTouch[3] & 0x038) == 0x000) && ((u32aCubeTouch[2] & 0x000) == 0x000) && ((u32aCubeTouch[1] & 0x092) == 0x002) && ((u32aCubeTouch[0] & 0x038) == 0x000)) // Start with 10
                )
            {
                u32Timer25ms_Delay10 = TOUCHTIME;
                enTouchState10 = TOUCH_002;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r10 (1st)"); 
                #endif
            }
            break;

        case TOUCH_002: // Waiting for 2nd touch -> 13

            if ( (0 == (u32aCubeTouch[1] & TOUCH1)) && (u32aCubeTouch[1] & TOUCH4) )
            {
                enTouchState10 = TOUCH_002_010; 
                u32Timer25ms_Delay10 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r13 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_002_010: // Waiting for 3rd touch -> 16

            if (u32aCubeTouch[1] & TOUCH7)
            {
                enTouchState10 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_05_04; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r16 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState10 [%d] ***", enTouchState10);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState10)

    // Touch 11
    
    switch (enTouchState11)
    {
        case TOUCH_IDLE: // Start with 11
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x000) == 0x000) && ((u32aCubeTouch[4] & 0x10C) == 0x000) && ((u32aCubeTouch[3] & 0x007) == 0x000) && ((u32aCubeTouch[2] & 0x1FF) == 0x000) && ((u32aCubeTouch[1] & 0x10C) == 0x004) && ((u32aCubeTouch[0] & 0x007) == 0x000)) // Start with 11
                    || ( ((u32aCubeTouch[5] & 0x10C) == 0x000) && ((u32aCubeTouch[4] & 0x1C0) == 0x000) && ((u32aCubeTouch[3] & 0x000) == 0x000) && ((u32aCubeTouch[2] & 0x10C) == 0x000) && ((u32aCubeTouch[1] & 0x007) == 0x004) && ((u32aCubeTouch[0] & 0x1FF) == 0x000)) // Start with 11                )
                )
            {
                u32Timer25ms_Delay11 = TOUCHTIME;
                enTouchState11 = TOUCH_004;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r11 (1st)"); 
                #endif
            }
            break;

        case TOUCH_004: // Waiting for 2nd touch
        
            if ( (0 == (u32aCubeTouch[1] & TOUCH2)) && (u32aCubeTouch[1] & TOUCH1) )
            {
                enTouchState11 = TOUCH_004_002; 
                u32Timer25ms_Delay11 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r10 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[1] & TOUCH2)) && (u32aCubeTouch[1] & TOUCH3) )
            {
                enTouchState11 = TOUCH_004_008; 
                u32Timer25ms_Delay11 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r12 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_004_002: // Waiting for 3rd touch -> 09

            if (u32aCubeTouch[1] & TOUCH0)
            {
                enTouchState11 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_11_10; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r09 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_004_008: // Waiting for 3rd touch -> 17

            if (u32aCubeTouch[1] & TOUCH8)
            {
                enTouchState11 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_00_01; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r17 (3rd)"); 
                #endif
            }
            break;
        
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState11 [%d] ***", enTouchState11);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState11)
     
    
    // Touch 12
    
    switch (enTouchState12)
    {
        case TOUCH_IDLE: // // Start with 12
        
            if (    
                   ( ((u32aCubeTouch[5] & 0x092) == 0x000) && ((u32aCubeTouch[4] & 0x038) == 0x000) && ((u32aCubeTouch[3] & 0x000) == 0x000) && ((u32aCubeTouch[2] & 0x092) == 0x000) && ((u32aCubeTouch[1] & 0x038) == 0x008) && ((u32aCubeTouch[0] & 0x000) == 0x000)) // Start with 12                )
            )
            {
                u32Timer25ms_Delay12 = TOUCHTIME;
                enTouchState12 = TOUCH_008;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r12 (1st)"); 
                #endif
            }
            break;

        case TOUCH_008: // Waiting for 2nd touch -> 13

            if ( (0 == (u32aCubeTouch[1] & TOUCH3)) && (u32aCubeTouch[1] & TOUCH4) )
            {
                enTouchState12 = TOUCH_008_010; 
                u32Timer25ms_Delay12 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r13 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_008_010: // Waiting for 3rd touch -> 14

            if (u32aCubeTouch[1] & TOUCH5)
            {
                enTouchState12 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_12_13; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r14 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState03 [%d] ***", enTouchState12);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState12)
    
    // Touch 14
    
    switch (enTouchState14)
    {
        case TOUCH_IDLE: // Start with 14
        
            if (    
                    ( ((u32aCubeTouch[5] & 0x092) == 0x000) && ((u32aCubeTouch[4] & 0x038) == 0x000) && ((u32aCubeTouch[3] & 0x000) == 0x000) && ((u32aCubeTouch[2] & 0x092) == 0x000) && ((u32aCubeTouch[1] & 0x038) == 0x020) && ((u32aCubeTouch[0] & 0x000) == 0x000)) // Start with 14
                )
            {
                u32Timer25ms_Delay14 = TOUCHTIME;
                enTouchState14 = TOUCH_020;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r14 (1st)"); 
                #endif
            }
            break;

        case TOUCH_020: // Waiting for 2nd touch -> 13

            if ( (0 == (u32aCubeTouch[1] & TOUCH5)) && (u32aCubeTouch[1] & TOUCH4) )
            {
                enTouchState14 = TOUCH_020_010; 
                u32Timer25ms_Delay14 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r13 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_020_010: // Waiting for 3rd touch -> 12

            if (u32aCubeTouch[1] & TOUCH3)
            {
                enTouchState14 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_13_12; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r12 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState14 [%d] ***", enTouchState14);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState14)
    
    // Touch 15
    
    switch (enTouchState15)
    {
        case TOUCH_IDLE: // Start with 15
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x061) == 0x000) && ((u32aCubeTouch[4] & 0x007) == 0x000) && ((u32aCubeTouch[3] & 0x1FF) == 0x000) && ((u32aCubeTouch[2] & 0x061) == 0x000) && ((u32aCubeTouch[1] & 0x1C0) == 0x040) && ((u32aCubeTouch[0] & 0x000) == 0x000)) // Start with 15
                    || ( ((u32aCubeTouch[5] & 0x1FF) == 0x000) && ((u32aCubeTouch[4] & 0x061) == 0x000) && ((u32aCubeTouch[3] & 0x1C0) == 0x000) && ((u32aCubeTouch[2] & 0x000) == 0x000) && ((u32aCubeTouch[1] & 0x061) == 0x040) && ((u32aCubeTouch[0] & 0x1C0) == 0x000)) // Start with 15
                )
            {
                u32Timer25ms_Delay15 = TOUCHTIME;
                enTouchState15 = TOUCH_040;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r15 (1st)"); 
                #endif
            }
            break;

        case TOUCH_040: // Waiting for 2nd touch -> 14 or 16
        
            if ( (0 == (u32aCubeTouch[1] & TOUCH6)) && (u32aCubeTouch[1] & TOUCH5) )
            {
                enTouchState15 = TOUCH_040_020; 
                u32Timer25ms_Delay15 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r14 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[1] & TOUCH6)) && (u32aCubeTouch[1] & TOUCH7) )
            {
                enTouchState15 = TOUCH_040_080; 
                u32Timer25ms_Delay15 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r16 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_040_020: // Waiting for 3rd touch -> 09

            if (u32aCubeTouch[1] & TOUCH0)
            {
                enTouchState15 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_07_06; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r09 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_040_080: // Waiting for 3rd touch -> 17

            if (u32aCubeTouch[1] & TOUCH8)
            {
                enTouchState15 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_16_17; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r17 (3rd)"); 
                #endif
            }
            break;
             
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState15 [%d] ***", enTouchState15);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState06)
  
    // Touch 16
    
    switch (enTouchState16)
    {
        case TOUCH_IDLE: // Start with 16
        
            if (    
                    ( ((u32aCubeTouch[5] & 0x000) == 0x000) && ((u32aCubeTouch[4] & 0x092) == 0x000) && ((u32aCubeTouch[3] & 0x038) == 0x000) && ((u32aCubeTouch[2] & 0x000) == 0x000) && ((u32aCubeTouch[1] & 0x092) == 0x080) && ((u32aCubeTouch[0] & 0x038) == 0x000)) // Start with 16
                )
            {
                u32Timer25ms_Delay16 = TOUCHTIME;
                enTouchState16 = TOUCH_080;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r16 (1st)"); 
                #endif
            }
            break;

        case TOUCH_080: // Waiting for 2nd touch -> 13

            if ( (0 == (u32aCubeTouch[1] & TOUCH7)) && (u32aCubeTouch[1] & TOUCH4) )
            {
                enTouchState16 = TOUCH_080_010; 
                u32Timer25ms_Delay16 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r13 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_080_010: // Waiting for 3rd touch -> 01

            if (u32aCubeTouch[1] & TOUCH1)
            {
                enTouchState16 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_04_05; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r10 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState16 [%d] ***", enTouchState16);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState16)

    // Touch 17
    
    switch (enTouchState17)
    {
        case TOUCH_IDLE: // Start with 17
        
            if (    
                      ( ((u32aCubeTouch[5] & 0x000) == 0x000) && ((u32aCubeTouch[4] & 0x10C) == 0x000) && ((u32aCubeTouch[3] & 0x007) == 0x000) && ((u32aCubeTouch[2] & 0x1FF) == 0x000) && ((u32aCubeTouch[1] & 0x10C) == 0x100) && ((u32aCubeTouch[0] & 0x007) == 0x000)) // Start with 17
                    ||( ((u32aCubeTouch[5] & 0x061) == 0x000) && ((u32aCubeTouch[4] & 0x007) == 0x000) && ((u32aCubeTouch[3] & 0x1FF) == 0x000) && ((u32aCubeTouch[2] & 0x061) == 0x000) && ((u32aCubeTouch[1] & 0x1C0) == 0x100) && ((u32aCubeTouch[0] & 0x000) == 0x000)) // Start with 17
                )
            {
                u32Timer25ms_Delay17 = TOUCHTIME;
                enTouchState17 = TOUCH_100;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r17 (1st)"); 
                #endif
            }
            break;

        case TOUCH_100: // Waiting for 2nd touch
        
            if ( (0 == (u32aCubeTouch[1] & TOUCH8)) && (u32aCubeTouch[1] & TOUCH3) )
            {
                enTouchState17 = TOUCH_100_008; 
                u32Timer25ms_Delay17 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r12 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[1] & TOUCH8)) && (u32aCubeTouch[1] & TOUCH7) )
            {
                enTouchState17 = TOUCH_100_080; 
                u32Timer25ms_Delay17 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r16 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_100_008: // Waiting for 3rd touch -> 11

            if (u32aCubeTouch[1] & TOUCH2)
            {
                enTouchState17 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_01_00; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r11 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_100_080: // Waiting for 3rd touch -> 15

            if (u32aCubeTouch[1] & TOUCH6)
            {
                enTouchState17 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_17_16; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r15 (3rd)"); 
                #endif
            }
            break;
        
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState17 [%d] ***", enTouchState17);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState17)
    #endif
    
    #ifdef P2
    // ------
    // PAGE 2
    // ------
    
    // Touch 18
    
    switch (enTouchState18)
    {
        case TOUCH_IDLE: // Start with 18
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x061) == 0x000) && ((u32aCubeTouch[4] & 0x007) == 0x000) && ((u32aCubeTouch[3] & 0x1FF) == 0x000) && ((u32aCubeTouch[2] & 0x061) == 0x001) && ((u32aCubeTouch[1] & 0x1C0) == 0x000) && ((u32aCubeTouch[0] & 0x000) == 0x000)) // Start with 18
                    || ( ((u32aCubeTouch[5] & 0x1C0) == 0x000) && ((u32aCubeTouch[4] & 0x000) == 0x000) && ((u32aCubeTouch[3] & 0x061) == 0x000) && ((u32aCubeTouch[2] & 0x007) == 0x001) && ((u32aCubeTouch[1] & 0x1FF) == 0x000) && ((u32aCubeTouch[0] & 0x10C) == 0x000)) // Start with 18
                )
            {
                u32Timer25ms_Delay18 = TOUCHTIME;
                enTouchState18 = TOUCH_001;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r18 (1st)"); 
                #endif
            }
            break;

        case TOUCH_001: // Waiting for 2nd touch -> 19 or 23
        
            if ( (0 == (u32aCubeTouch[2] & TOUCH0)) && (u32aCubeTouch[2] & TOUCH1) )
            {
                enTouchState18 = TOUCH_001_002; 
                u32Timer25ms_Delay18 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r19 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[2] & TOUCH0)) && (u32aCubeTouch[2] & TOUCH5) )
            {
                enTouchState18 = TOUCH_001_020; 
                u32Timer25ms_Delay18 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r23 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_001_002: // Waiting for 3rd touch -> 20

            if (u32aCubeTouch[2] & TOUCH2)
            {
                enTouchState18 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_02_03; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r20 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_001_020: // Waiting for 3rd touch -> 24

            if (u32aCubeTouch[2] & TOUCH6)
            {
                enTouchState18 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_16_17; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r24 (3rd)"); 
                #endif
            }
            break;
             
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState18 [%d] ***", enTouchState18);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState18)
  
    // Touch 19
    
    switch (enTouchState19)
    {
        case TOUCH_IDLE: // Start with 19
        
            if (    
                    ( ((u32aCubeTouch[5] & 0x092) == 0x000) && ((u32aCubeTouch[4] & 0x038) == 0x000) && ((u32aCubeTouch[3] & 0x000) == 0x000) && ((u32aCubeTouch[2] & 0x092) == 0x002) && ((u32aCubeTouch[1] & 0x038) == 0x000) && ((u32aCubeTouch[0] & 0x000) == 0x000)) // Start with 19
                )
            {
                u32Timer25ms_Delay19 = TOUCHTIME;
                enTouchState19 = TOUCH_002;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r19 (1st)"); 
                #endif
            }
            break;

        case TOUCH_002: // Waiting for 2nd touch -> 22

            if ( (0 == (u32aCubeTouch[2] & TOUCH1)) && (u32aCubeTouch[2] & TOUCH4) )
            {
                enTouchState19 = TOUCH_002_010; 
                u32Timer25ms_Delay19 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r22 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_002_010: // Waiting for 3rd touch -> 25

            if (u32aCubeTouch[2] & TOUCH7)
            {
                enTouchState19 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_13_12; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r25 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState19 [%d] ***", enTouchState19);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState19)

    // Touch 20
    
    switch (enTouchState20)
    {
        case TOUCH_IDLE: // Start with 20
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x1C0) == 0x000) && ((u32aCubeTouch[4] & 0x000) == 0x000) && ((u32aCubeTouch[3] & 0x061) == 0x000) && ((u32aCubeTouch[2] & 0x007) == 0x004) && ((u32aCubeTouch[1] & 0x1FF) == 0x000) && ((u32aCubeTouch[0] & 0x10C) == 0x000)) // Start with 20
                    || ( ((u32aCubeTouch[5] & 0x10C) == 0x000) && ((u32aCubeTouch[4] & 0x1C0) == 0x000) && ((u32aCubeTouch[3] & 0x000) == 0x000) && ((u32aCubeTouch[2] & 0x10C) == 0x004) && ((u32aCubeTouch[1] & 0x007) == 0x000) && ((u32aCubeTouch[0] & 0x1FF) == 0x000)) // Start with 20
                )
            {
                u32Timer25ms_Delay20 = TOUCHTIME;
                enTouchState20 = TOUCH_004;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r20 (1st)"); 
                #endif
            }
            break;

        case TOUCH_004: // Waiting for 2nd touch
        
            if ( (0 == (u32aCubeTouch[2] & TOUCH2)) && (u32aCubeTouch[2] & TOUCH1) )
            {
                enTouchState20 = TOUCH_004_002; 
                u32Timer25ms_Delay20 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r19 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[2] & TOUCH2)) && (u32aCubeTouch[2] & TOUCH3) )
            {
                enTouchState20 = TOUCH_004_008; 
                u32Timer25ms_Delay20 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r21 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_004_002: // Waiting for 3rd touch -> 18

            if (u32aCubeTouch[2] & TOUCH0)
            {
                enTouchState20 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_03_02; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r18 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_004_008: // Waiting for 3rd touch -> 26

            if (u32aCubeTouch[2] & TOUCH8)
            {
                enTouchState20 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_10_11; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r26 (3rd)"); 
                #endif
            }
            break;
        
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState20 [%d] ***", enTouchState20);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState20)
     
    
    // Touch 21
    
    switch (enTouchState21)
    {
        case TOUCH_IDLE: // // Start with 21
        
            if (    
                    ( ((u32aCubeTouch[5] & 0x038) == 0x000) && ((u32aCubeTouch[4] & 0x000) == 0x000) && ((u32aCubeTouch[3] & 0x092) == 0x000) && ((u32aCubeTouch[2] & 0x038) == 0x008) && ((u32aCubeTouch[1] & 0x000) == 0x000) && ((u32aCubeTouch[0] & 0x092) == 0x000)) // Start with 21
            )
            {
                u32Timer25ms_Delay21 = TOUCHTIME;
                enTouchState21 = TOUCH_008;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r21 (1st)"); 
                #endif
            }
            break;

        case TOUCH_008: // Waiting for 2nd touch -> 22

            if ( (0 == (u32aCubeTouch[2] & TOUCH3)) && (u32aCubeTouch[2] & TOUCH4) )
            {
                enTouchState21 = TOUCH_008_010; 
                u32Timer25ms_Delay21 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r22 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_008_010: // Waiting for 3rd touch -> 23

            if (u32aCubeTouch[2] & TOUCH5)
            {
                enTouchState21 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_04_01; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r23 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState21 [%d] ***", enTouchState21);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState21)
    
    // Touch 23
    
    switch (enTouchState23)
    {
        case TOUCH_IDLE: // Start with 23
        
            if (    
                    ( ((u32aCubeTouch[5] & 0x038) == 0x000) && ((u32aCubeTouch[4] & 0x000) == 0x000) && ((u32aCubeTouch[3] & 0x092) == 0x000) && ((u32aCubeTouch[2] & 0x038) == 0x020) && ((u32aCubeTouch[1] & 0x000) == 0x000) && ((u32aCubeTouch[0] & 0x092) == 0x000)) // Start with 23
                )
            {
                u32Timer25ms_Delay23 = TOUCHTIME;
                enTouchState23 = TOUCH_020;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r23 (1st)"); 
                #endif
            }
            break;

        case TOUCH_020: // Waiting for 2nd touch -> 22

            if ( (0 == (u32aCubeTouch[2] & TOUCH5)) && (u32aCubeTouch[2] & TOUCH4) )
            {
                enTouchState23 = TOUCH_020_010; 
                u32Timer25ms_Delay23 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r22 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_020_010: // Waiting for 3rd touch -> 21

            if (u32aCubeTouch[2] & TOUCH3)
            {
                enTouchState23 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_01_04; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r21 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState23 [%d] ***", enTouchState23);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState23)
    
    // Touch 24
    
    switch (enTouchState24)
    {
        case TOUCH_IDLE: // Start with 24
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x007) == 0x000) && ((u32aCubeTouch[4] & 0x1FF) == 0x000) && ((u32aCubeTouch[3] & 0x10C) == 0x000) && ((u32aCubeTouch[2] & 0x1C0) == 0x040) && ((u32aCubeTouch[1] & 0x000) == 0x000) && ((u32aCubeTouch[0] & 0x061) == 0x000)) // Start with 24
                    || ( ((u32aCubeTouch[5] & 0x061) == 0x000) && ((u32aCubeTouch[4] & 0x007) == 0x000) && ((u32aCubeTouch[3] & 0x1FF) == 0x000) && ((u32aCubeTouch[2] & 0x061) == 0x040) && ((u32aCubeTouch[1] & 0x1C0) == 0x000) && ((u32aCubeTouch[0] & 0x000) == 0x000)) // Start with 24
                )
            {
                u32Timer25ms_Delay24 = TOUCHTIME;
                enTouchState24 = TOUCH_040;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r24 (1st)"); 
                #endif
            }
            break;

        case TOUCH_040: // Waiting for 2nd touch -> 23 or 25
        
            if ( (0 == (u32aCubeTouch[2] & TOUCH6)) && (u32aCubeTouch[2] & TOUCH5) )
            {
                enTouchState24 = TOUCH_040_020; 
                u32Timer25ms_Delay24 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r23 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[2] & TOUCH6)) && (u32aCubeTouch[2] & TOUCH7) )
            {
                enTouchState24 = TOUCH_040_080; 
                u32Timer25ms_Delay24 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r25 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_040_020: // Waiting for 3rd touch -> 18

            if (u32aCubeTouch[2] & TOUCH0)
            {
                enTouchState24 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_17_16; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r18 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_040_080: // Waiting for 3rd touch -> 26

            if (u32aCubeTouch[2] & TOUCH8)
            {
                enTouchState24 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_00_05; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r26 (3rd)"); 
                #endif
            }
            break;
             
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState24 [%d] ***", enTouchState24);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState24)
  
    // Touch 25
    
    switch (enTouchState25)
    {
        case TOUCH_IDLE: // Start with 25
        
            if (    
                    ( ((u32aCubeTouch[5] & 0x092) == 0x000) && ((u32aCubeTouch[4] & 0x038) == 0x000) && ((u32aCubeTouch[3] & 0x000) == 0x000) && ((u32aCubeTouch[2] & 0x092) == 0x080) && ((u32aCubeTouch[1] & 0x038) == 0x000) && ((u32aCubeTouch[0] & 0x000) == 0x000)) // Start with 25
                )
            {
                u32Timer25ms_Delay25 = TOUCHTIME;
                enTouchState25 = TOUCH_080;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r25 (1st)"); 
                #endif
            }
            break;

        case TOUCH_080: // Waiting for 2nd touch -> 22

            if ( (0 == (u32aCubeTouch[2] & TOUCH7)) && (u32aCubeTouch[2] & TOUCH4) )
            {
                enTouchState25 = TOUCH_080_010; 
                u32Timer25ms_Delay25 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r22 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_080_010: // Waiting for 3rd touch -> 19

            if (u32aCubeTouch[2] & TOUCH1)
            {
                enTouchState25 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_12_13; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r19 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState25 [%d] ***", enTouchState25);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState25)

    // Touch 26
    
    switch (enTouchState26)
    {
        case TOUCH_IDLE: // Start with 26
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x007) == 0x000) && ((u32aCubeTouch[4] & 0x1FF) == 0x000) && ((u32aCubeTouch[3] & 0x10C) == 0x000) && ((u32aCubeTouch[2] & 0x1C0) == 0x100) && ((u32aCubeTouch[1] & 0x000) == 0x000) && ((u32aCubeTouch[0] & 0x061) == 0x000)) // Start with 26
                    || ( ((u32aCubeTouch[5] & 0x10C) == 0x000) && ((u32aCubeTouch[4] & 0x1C0) == 0x000) && ((u32aCubeTouch[3] & 0x000) == 0x000) && ((u32aCubeTouch[2] & 0x10C) == 0x100) && ((u32aCubeTouch[1] & 0x007) == 0x000) && ((u32aCubeTouch[0] & 0x1FF) == 0x000)) // Start with 26
                )
            {
                u32Timer25ms_Delay26 = TOUCHTIME;
                enTouchState26 = TOUCH_100;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r26 (1st)"); 
                #endif
            }
            break;

        case TOUCH_100: // Waiting for 2nd touch
        
            if ( (0 == (u32aCubeTouch[2] & TOUCH8)) && (u32aCubeTouch[2] & TOUCH3) )
            {
                enTouchState26 = TOUCH_100_008; 
                u32Timer25ms_Delay26 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r21 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[2] & TOUCH8)) && (u32aCubeTouch[2] & TOUCH7) )
            {
                enTouchState26 = TOUCH_100_080; 
                u32Timer25ms_Delay26 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r25 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_100_008: // Waiting for 3rd touch -> 20

            if (u32aCubeTouch[2] & TOUCH2)
            {
                enTouchState26 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_11_10; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r11 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_100_080: // Waiting for 3rd touch -> 24

            if (u32aCubeTouch[2] & TOUCH6)
            {
                enTouchState26 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_05_00; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r24 (3rd)"); 
                #endif
            }
            break;
        
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState26 [%d] ***", enTouchState26);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState26)
    #endif
    
    #ifdef P3
    // ------
    // PAGE 3
    // ------
    
    // Touch 27
    
    switch (enTouchState27)
    {
        case TOUCH_IDLE: // Start with 27
        
            if (    
                       (  ((u32aCubeTouch[5] & 0x000) == 0x000) && ((u32aCubeTouch[4] & 0x10C) == 0x000) && ((u32aCubeTouch[3] & 0x007) == 0x001) && ((u32aCubeTouch[2] & 0x1FF) == 0x000) && ((u32aCubeTouch[1] & 0x10C) == 0x000) && ((u32aCubeTouch[0] & 0x007) == 0x000)) // Start with 27
                    || ( ((u32aCubeTouch[5] & 0x1C0) == 0x000) && ((u32aCubeTouch[4] & 0x000) == 0x000) && ((u32aCubeTouch[3] & 0x061) == 0x001) && ((u32aCubeTouch[2] & 0x007) == 0x000) && ((u32aCubeTouch[1] & 0x1FF) == 0x000) && ((u32aCubeTouch[0] & 0x10C) == 0x000)) // Start with 27
                )
            {
                u32Timer25ms_Delay27 = TOUCHTIME;
                enTouchState27 = TOUCH_001;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r27 (1st)"); 
                #endif
            }
            break;

        case TOUCH_001: // Waiting for 2nd touch -> 28 or 32
        
            if ( (0 == (u32aCubeTouch[3] & TOUCH0)) && (u32aCubeTouch[3] & TOUCH1) )
            {
                enTouchState27 = TOUCH_001_002; 
                u32Timer25ms_Delay27 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r28 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[3] & TOUCH0)) && (u32aCubeTouch[3] & TOUCH5) )
            {
                enTouchState27 = TOUCH_001_020; 
                u32Timer25ms_Delay27 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r32 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_001_002: // Waiting for 3rd touch -> 29

            if (u32aCubeTouch[3] & TOUCH2)
            {
                enTouchState27 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_00_01; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r29 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_001_020: // Waiting for 3rd touch -> 33

            if (u32aCubeTouch[3] & TOUCH6)
            {
                enTouchState27 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_03_02; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r33 (3rd)"); 
                #endif
            }
            break;
             
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState27 [%d] ***", enTouchState27);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState27)
  
    // Touch 28
    
    switch (enTouchState28)
    {
        case TOUCH_IDLE: // Start with 28
        
            if (    
                    ( ((u32aCubeTouch[5] & 0x038) == 0x000) && ((u32aCubeTouch[4] & 0x000) == 0x000) && ((u32aCubeTouch[3] & 0x092) == 0x002) && ((u32aCubeTouch[2] & 0x038) == 0x000) && ((u32aCubeTouch[1] & 0x000) == 0x000) && ((u32aCubeTouch[0] & 0x092) == 0x000)) // Start with 28
                )
            {
                u32Timer25ms_Delay28 = TOUCHTIME;
                enTouchState28 = TOUCH_002;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r28 (1st)"); 
                #endif
            }
            break;

        case TOUCH_002: // Waiting for 2nd touch -> 31

            if ( (0 == (u32aCubeTouch[3] & TOUCH1)) && (u32aCubeTouch[3] & TOUCH4) )
            {
                enTouchState28 = TOUCH_002_010; 
                u32Timer25ms_Delay28 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r31 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_002_010: // Waiting for 3rd touch -> 34

            if (u32aCubeTouch[3] & TOUCH7)
            {
                enTouchState28 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_04_01; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r34 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState28 [%d] ***", enTouchState28);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState128)

    // Touch 29
    
    switch (enTouchState29)
    {
        case TOUCH_IDLE: // Start with 29
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x007) == 0x000) && ((u32aCubeTouch[4] & 0x1FF) == 0x000) && ((u32aCubeTouch[3] & 0x10C) == 0x004) && ((u32aCubeTouch[2] & 0x1C0) == 0x000) && ((u32aCubeTouch[1] & 0x000) == 0x000) && ((u32aCubeTouch[0] & 0x061) == 0x000)) // Start with 29
                    || ( ((u32aCubeTouch[5] & 0x000) == 0x000) && ((u32aCubeTouch[4] & 0x10C) == 0x000) && ((u32aCubeTouch[3] & 0x007) == 0x004) && ((u32aCubeTouch[2] & 0x1FF) == 0x000) && ((u32aCubeTouch[1] & 0x10C) == 0x000) && ((u32aCubeTouch[0] & 0x007) == 0x000)) // Start with 29
                )
            {
                u32Timer25ms_Delay29 = TOUCHTIME;
                enTouchState29 = TOUCH_004;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r29 (1st)"); 
                #endif
            }
            break;

        case TOUCH_004: // Waiting for 2nd touch
        
            if ( (0 == (u32aCubeTouch[3] & TOUCH2)) && (u32aCubeTouch[3] & TOUCH1) )
            {
                enTouchState29 = TOUCH_004_002; 
                u32Timer25ms_Delay29 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r28 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[3] & TOUCH2)) && (u32aCubeTouch[3] & TOUCH3) )
            {
                enTouchState29 = TOUCH_004_008; 
                u32Timer25ms_Delay29 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r30 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_004_002: // Waiting for 3rd touch -> 27

            if (u32aCubeTouch[3] & TOUCH0)
            {
                enTouchState29 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_01_00; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r27 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_004_008: // Waiting for 3rd touch -> 35

            if (u32aCubeTouch[3] & TOUCH8)
            {
                enTouchState29 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_05_00; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r35 (3rd)"); 
                #endif
            }
            break;
        
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState29 [%d] ***", enTouchState29);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState29)
     
    
    // Touch 30
    
    switch (enTouchState30)
    {
        case TOUCH_IDLE: // // Start with 30
        
            if (    
                    ( ((u32aCubeTouch[5] & 0x000) == 0x000) && ((u32aCubeTouch[4] & 0x092) == 0x000) && ((u32aCubeTouch[3] & 0x038) == 0x008) && ((u32aCubeTouch[2] & 0x000) == 0x000) && ((u32aCubeTouch[1] & 0x092) == 0x000) && ((u32aCubeTouch[0] & 0x038) == 0x000)) // Start with 30
            )
            {
                u32Timer25ms_Delay30 = TOUCHTIME;
                enTouchState30 = TOUCH_008;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r30 (1st)"); 
                #endif
            }
            break;

        case TOUCH_008: // Waiting for 2nd touch -> 31

            if ( (0 == (u32aCubeTouch[3] & TOUCH3)) && (u32aCubeTouch[3] & TOUCH4) )
            {
                enTouchState30 = TOUCH_008_010; 
                u32Timer25ms_Delay30 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r31 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_008_010: // Waiting for 3rd touch -> 32

            if (u32aCubeTouch[3] & TOUCH5)
            {
                enTouchState30 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_04_05; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r32 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState30 [%d] ***", enTouchState30);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState30)
    
    // Touch 32
    
    switch (enTouchState32)
    {
        case TOUCH_IDLE: // Start with 32
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x000) == 0x000) && ((u32aCubeTouch[4] & 0x092) == 0x000) && ((u32aCubeTouch[3] & 0x038) == 0x020) && ((u32aCubeTouch[2] & 0x000) == 0x000) && ((u32aCubeTouch[1] & 0x092) == 0x000) && ((u32aCubeTouch[0] & 0x038) == 0x000)) // Start with 32
                )
            {
                u32Timer25ms_Delay32 = TOUCHTIME;
                enTouchState32 = TOUCH_020;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r32 (1st)"); 
                #endif
            }
            break;

        case TOUCH_020: // Waiting for 2nd touch -> 31

            if ( (0 == (u32aCubeTouch[3] & TOUCH5)) && (u32aCubeTouch[3] & TOUCH4) )
            {
                enTouchState32 = TOUCH_020_010; 
                u32Timer25ms_Delay32 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r31 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_020_010: // Waiting for 3rd touch -> 30

            if (u32aCubeTouch[3] & TOUCH3)
            {
                enTouchState32 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_05_04; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r30 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState32 [%d] ***", enTouchState32);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState32)
    
    // Touch 33
    
    switch (enTouchState33)
    {
        case TOUCH_IDLE: // Start with 33
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x1FF) == 0x000) && ((u32aCubeTouch[4] & 0x061) == 0x000) && ((u32aCubeTouch[3] & 0x1C0) == 0x040) && ((u32aCubeTouch[2] & 0x000) == 0x000) && ((u32aCubeTouch[1] & 0x061) == 0x000) && ((u32aCubeTouch[0] & 0x1C0) == 0x000)) // Start with 33
                    || ( ((u32aCubeTouch[5] & 0x1C0) == 0x000) && ((u32aCubeTouch[4] & 0x000) == 0x000) && ((u32aCubeTouch[3] & 0x061) == 0x040) && ((u32aCubeTouch[2] & 0x007) == 0x000) && ((u32aCubeTouch[1] & 0x1FF) == 0x000) && ((u32aCubeTouch[0] & 0x10C) == 0x000)) // Start with 33
                )
            {
                u32Timer25ms_Delay33 = TOUCHTIME;
                enTouchState33 = TOUCH_040;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r33 (1st)"); 
                #endif
            }
            break;

        case TOUCH_040: // Waiting for 2nd touch -> 32 or 34
        
            if ( (0 == (u32aCubeTouch[3] & TOUCH6)) && (u32aCubeTouch[3] & TOUCH5) )
            {
                enTouchState33 = TOUCH_040_020; 
                u32Timer25ms_Delay33 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r32 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[3] & TOUCH6)) && (u32aCubeTouch[3] & TOUCH7) )
            {
                enTouchState33 = TOUCH_040_080; 
                u32Timer25ms_Delay33 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r34 (2nd)"); 
                #endif
            }
            break;
       
        case TOUCH_040_020: // Waiting for 3rd touch -> 27

            if (u32aCubeTouch[3] & TOUCH0)
            {
                enTouchState33 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_02_03; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r27 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_040_080: // Waiting for 3rd touch -> 35

            if (u32aCubeTouch[3] & TOUCH8)
            {
                enTouchState33 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_06_07; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r35 (3rd)"); 
                #endif
            }
            break;
             
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState33 [%d] ***", enTouchState33);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState33)
  
    // Touch 34
    
    switch (enTouchState34)
    {
        case TOUCH_IDLE: // Start with 34
        
            if (    
                    ( ((u32aCubeTouch[5] & 0x038) == 0x000) && ((u32aCubeTouch[4] & 0x000) == 0x000) && ((u32aCubeTouch[3] & 0x092) == 0x080) && ((u32aCubeTouch[2] & 0x038) == 0x000) && ((u32aCubeTouch[1] & 0x000) == 0x000) && ((u32aCubeTouch[0] & 0x092) == 0x000)) // Start with 34
                )
            {
                u32Timer25ms_Delay34 = TOUCHTIME;
                enTouchState34 = TOUCH_080;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r34 (1st)"); 
                #endif
            }
            break;

        case TOUCH_080: // Waiting for 2nd touch -> 31

            if ( (0 == (u32aCubeTouch[3] & TOUCH7)) && (u32aCubeTouch[3] & TOUCH4) )
            {
                enTouchState34 = TOUCH_080_010; 
                u32Timer25ms_Delay34 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r31 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_080_010: // Waiting for 3rd touch -> 28

            if (u32aCubeTouch[3] & TOUCH1)
            {
                enTouchState34 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_01_04; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r28 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState34 [%d] ***", enTouchState34);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState34)

    // Touch 35
    
    switch (enTouchState35)
    {
        case TOUCH_IDLE: // Start with 35
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x007) == 0x000) && ((u32aCubeTouch[4] & 0x1FF) == 0x000) && ((u32aCubeTouch[3] & 0x10C) == 0x100) && ((u32aCubeTouch[2] & 0x1C0) == 0x000) && ((u32aCubeTouch[1] & 0x000) == 0x000) && ((u32aCubeTouch[0] & 0x061) == 0x000)) // Start with 35
                    || ( ((u32aCubeTouch[5] & 0x1FF) == 0x000) && ((u32aCubeTouch[4] & 0x061) == 0x000) && ((u32aCubeTouch[3] & 0x1C0) == 0x100) && ((u32aCubeTouch[2] & 0x000) == 0x000) && ((u32aCubeTouch[1] & 0x061) == 0x000) && ((u32aCubeTouch[0] & 0x1C0) == 0x000)) // Start with 35
                )
            {
                u32Timer25ms_Delay35 = TOUCHTIME;
                enTouchState35 = TOUCH_100;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r35 (1st)"); 
                #endif
            }
            break;

        case TOUCH_100: // Waiting for 2nd touch -> 30 or 34
        
            if ( (0 == (u32aCubeTouch[3] & TOUCH8)) && (u32aCubeTouch[3] & TOUCH3) )
            {
                enTouchState35 = TOUCH_100_008; 
                u32Timer25ms_Delay35 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r30 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[3] & TOUCH8)) && (u32aCubeTouch[3] & TOUCH7) )
            {
                enTouchState35 = TOUCH_100_080; 
                u32Timer25ms_Delay35 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r34 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_100_008: // Waiting for 3rd touch -> 29

            if (u32aCubeTouch[3] & TOUCH2)
            {
                enTouchState35 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_00_05; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r29 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_100_080: // Waiting for 3rd touch -> 33

            if (u32aCubeTouch[3] & TOUCH6)
            {
                enTouchState35 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_07_06; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r33 (3rd)"); 
                #endif
            }
            break;
        
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState35 [%d] ***", enTouchState35);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState35)
    #endif
    
    #ifdef P4
    // ------
    // PAGE 4
    // ------
    
    // Touch 36
    
    switch (enTouchState36)
    {
        case TOUCH_IDLE: // Start with 36
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x1FF) == 0x000) && ((u32aCubeTouch[4] & 0x061) == 0x001) && ((u32aCubeTouch[3] & 0x1C0) == 0x000) && ((u32aCubeTouch[2] & 0x000) == 0x000) && ((u32aCubeTouch[1] & 0x061) == 0x000) && ((u32aCubeTouch[0] & 0x1C0) == 0x000)) // Start with 36
                    || ( ((u32aCubeTouch[5] & 0x061) == 0x000) && ((u32aCubeTouch[4] & 0x007) == 0x001) && ((u32aCubeTouch[3] & 0x1FF) == 0x000) && ((u32aCubeTouch[2] & 0x061) == 0x000) && ((u32aCubeTouch[1] & 0x1C0) == 0x000) && ((u32aCubeTouch[0] & 0x000) == 0x000)) // Start with 36
                )
            {
                u32Timer25ms_Delay36 = TOUCHTIME;
                enTouchState36 = TOUCH_001;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r36 (1st)"); 
                #endif
            }
            break;

        case TOUCH_001: // Waiting for 2nd touch -> 37 or 41
        
            if ( (0 == (u32aCubeTouch[4] & TOUCH0)) && (u32aCubeTouch[4] & TOUCH1) )
            {
                enTouchState36 = TOUCH_001_002; 
                u32Timer25ms_Delay36 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r37 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[4] & TOUCH0)) && (u32aCubeTouch[4] & TOUCH5) )
            {
                enTouchState36 = TOUCH_001_020; 
                u32Timer25ms_Delay36 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r41 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_001_002: // Waiting for 3rd touch -> 38

            if (u32aCubeTouch[4] & TOUCH2)
            {
                enTouchState36 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_17_16; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r38 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_001_020: // Waiting for 3rd touch -> 42

            if (u32aCubeTouch[4] & TOUCH6)
            {
                enTouchState36 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_06_07; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r42 (3rd)"); 
                #endif
            }
            break;
             
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState36 [%d] ***", enTouchState36);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState36)
  
    // Touch 37
    
    switch (enTouchState37)
    {
        case TOUCH_IDLE: // Start with 37
        
            if (    
                    ( ((u32aCubeTouch[5] & 0x000) == 0x000) && ((u32aCubeTouch[4] & 0x092) == 0x002) && ((u32aCubeTouch[3] & 0x038) == 0x000) && ((u32aCubeTouch[2] & 0x000) == 0x000) && ((u32aCubeTouch[1] & 0x092) == 0x000) && ((u32aCubeTouch[0] & 0x038) == 0x000)) // Start with 37
                )
            {
                u32Timer25ms_Delay37 = TOUCHTIME;
                enTouchState37 = TOUCH_002;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r37 (1st)"); 
                #endif
            }
            break;

        case TOUCH_002: // Waiting for 2nd touch -> 40

            if ( (0 == (u32aCubeTouch[4] & TOUCH1)) && (u32aCubeTouch[4] & TOUCH4) )
            {
                enTouchState37 = TOUCH_002_010; 
                u32Timer25ms_Delay37 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r40 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_002_010: // Waiting for 3rd touch -> 43

            if (u32aCubeTouch[4] & TOUCH7)
            {
                enTouchState37 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_05_04; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r43 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState37 [%d] ***", enTouchState37);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState37)

    // Touch 38
    
    switch (enTouchState38)
    {
        case TOUCH_IDLE: // Start with 38
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x061) == 0x000) && ((u32aCubeTouch[4] & 0x007) == 0x004) && ((u32aCubeTouch[3] & 0x1FF) == 0x000) && ((u32aCubeTouch[2] & 0x061) == 0x000) && ((u32aCubeTouch[1] & 0x1C0) == 0x000) && ((u32aCubeTouch[0] & 0x000) == 0x000)) // Start with 38
                    || ( ((u32aCubeTouch[5] & 0x000) == 0x000) && ((u32aCubeTouch[4] & 0x10C) == 0x004) && ((u32aCubeTouch[3] & 0x007) == 0x000) && ((u32aCubeTouch[2] & 0x1FF) == 0x000) && ((u32aCubeTouch[1] & 0x10C) == 0x000) && ((u32aCubeTouch[0] & 0x007) == 0x000)) // Start with 38
                )
            {
                u32Timer25ms_Delay38 = TOUCHTIME;
                enTouchState38 = TOUCH_004;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r38 (1st)"); 
                #endif
            }
            break;

        case TOUCH_004: // Waiting for 2nd touch -> 37 or 39
        
            if ( (0 == (u32aCubeTouch[4] & TOUCH2)) && (u32aCubeTouch[4] & TOUCH1) )
            {
                enTouchState38 = TOUCH_004_002; 
                u32Timer25ms_Delay38 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r37 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[4] & TOUCH2)) && (u32aCubeTouch[4] & TOUCH3) )
            {
                enTouchState38 = TOUCH_004_008; 
                u32Timer25ms_Delay38 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r39 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_004_002: // Waiting for 3rd touch -> 36

            if (u32aCubeTouch[4] & TOUCH0)
            {
                enTouchState38 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_16_17; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r36 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_004_008: // Waiting for 3rd touch -> 44

            if (u32aCubeTouch[4] & TOUCH8)
            {
                enTouchState38 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_00_01; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r44 (3rd)"); 
                #endif
            }
            break;
        
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState38 [%d] ***", enTouchState38);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState38)
     
    
    // Touch 39
    
    switch (enTouchState39)
    {
        case TOUCH_IDLE: // // Start with 39
        
            if (    
                    ( ((u32aCubeTouch[5] & 0x092) == 0x000) && ((u32aCubeTouch[4] & 0x038) == 0x008) && ((u32aCubeTouch[3] & 0x000) == 0x000) && ((u32aCubeTouch[2] & 0x092) == 0x000) && ((u32aCubeTouch[1] & 0x038) == 0x000) && ((u32aCubeTouch[0] & 0x000) == 0x000)) // Start with 39
            )
            {
                u32Timer25ms_Delay39 = TOUCHTIME;
                enTouchState39 = TOUCH_008;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r39 (1st)"); 
                #endif
            }
            break;

        case TOUCH_008: // Waiting for 2nd touch -> 40

            if ( (0 == (u32aCubeTouch[4] & TOUCH3)) && (u32aCubeTouch[4] & TOUCH4) )
            {
                enTouchState39 = TOUCH_008_010; 
                u32Timer25ms_Delay39 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r40 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_008_010: // Waiting for 3rd touch -> 41

            if (u32aCubeTouch[4] & TOUCH5)
            {
                enTouchState39 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_13_12; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r41 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState39 [%d] ***", enTouchState39);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState39)
    
    // Touch 41
    
    switch (enTouchState41)
    {
        case TOUCH_IDLE: // Start with 41
        
            if (    
                    ( ((u32aCubeTouch[5] & 0x092) == 0x000) && ((u32aCubeTouch[4] & 0x038) == 0x020) && ((u32aCubeTouch[3] & 0x000) == 0x000) && ((u32aCubeTouch[2] & 0x092) == 0x000) && ((u32aCubeTouch[1] & 0x038) == 0x000) && ((u32aCubeTouch[0] & 0x000) == 0x000)) // Start with 41
                )
            {
                u32Timer25ms_Delay41 = TOUCHTIME;
                enTouchState41 = TOUCH_020;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r41 (1st)"); 
                #endif
            }
            break;

        case TOUCH_020: // Waiting for 2nd touch -> 40

            if ( (0 == (u32aCubeTouch[4] & TOUCH5)) && (u32aCubeTouch[4] & TOUCH4) )
            {
                enTouchState41 = TOUCH_020_010; 
                u32Timer25ms_Delay41 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r40 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_020_010: // Waiting for 3rd touch -> 39

            if (u32aCubeTouch[4] & TOUCH3)
            {
                enTouchState41 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_12_13; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r39 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState41 [%d] ***", enTouchState41);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState32)
    
    // Touch 42
    
    switch (enTouchState42)
    {
        case TOUCH_IDLE: // Start with 42
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x1FF) == 0x000) && ((u32aCubeTouch[4] & 0x061) == 0x040) && ((u32aCubeTouch[3] & 0x1C0) == 0x000) && ((u32aCubeTouch[2] & 0x000) == 0x000) && ((u32aCubeTouch[1] & 0x061) == 0x000) && ((u32aCubeTouch[0] & 0x1C0) == 0x000)) // Start with 42
                    || ( ((u32aCubeTouch[5] & 0x10C) == 0x000) && ((u32aCubeTouch[4] & 0x1C0) == 0x040) && ((u32aCubeTouch[3] & 0x000) == 0x000) && ((u32aCubeTouch[2] & 0x10C) == 0x000) && ((u32aCubeTouch[1] & 0x007) == 0x000) && ((u32aCubeTouch[0] & 0x1FF) == 0x000)) // Start with 42
                )
            {
                u32Timer25ms_Delay42 = TOUCHTIME;
                enTouchState42 = TOUCH_040;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r42 (1st)"); 
                #endif
            }
            break;

        case TOUCH_040: // Waiting for 2nd touch -> 41 or 43
        
            if ( (0 == (u32aCubeTouch[4] & TOUCH6)) && (u32aCubeTouch[4] & TOUCH5) )
            {
                enTouchState42 = TOUCH_040_020; 
                u32Timer25ms_Delay42 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r41 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[4] & TOUCH6)) && (u32aCubeTouch[4] & TOUCH7) )
            {
                enTouchState42 = TOUCH_040_080; 
                u32Timer25ms_Delay42 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r43 (2nd)"); 
                #endif
            }
            break;
       
        case TOUCH_040_020: // Waiting for 3rd touch -> 36

            if (u32aCubeTouch[4] & TOUCH0)
            {
                enTouchState42 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_07_06; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r36 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_040_080: // Waiting for 3rd touch -> 44

            if (u32aCubeTouch[4] & TOUCH8)
            {
                enTouchState42 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_11_10; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r44 (3rd)"); 
                #endif
            }
            break;
             
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState42 [%d] ***", enTouchState42);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState42)
  
    // Touch 43
    
    switch (enTouchState43)
    {
        case TOUCH_IDLE: // Start with 43
        
            if (    
                    ( ((u32aCubeTouch[5] & 0x000) == 0x000) && ((u32aCubeTouch[4] & 0x092) == 0x080) && ((u32aCubeTouch[3] & 0x038) == 0x000) && ((u32aCubeTouch[2] & 0x000) == 0x000) && ((u32aCubeTouch[1] & 0x092) == 0x000) && ((u32aCubeTouch[0] & 0x038) == 0x000)) // Start with 43
                )
            {
                u32Timer25ms_Delay43 = TOUCHTIME;
                enTouchState43 = TOUCH_080;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r43 (1st)"); 
                #endif
            }
            break;

        case TOUCH_080: // Waiting for 2nd touch -> 40

            if ( (0 == (u32aCubeTouch[4] & TOUCH7)) && (u32aCubeTouch[4] & TOUCH4) )
            {
                enTouchState43 = TOUCH_080_010; 
                u32Timer25ms_Delay43 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r40 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_080_010: // Waiting for 3rd touch -> 37

            if (u32aCubeTouch[4] & TOUCH1)
            {
                enTouchState43 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_04_05; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r37 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState43 [%d] ***", enTouchState43);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState43)

    // Touch 44
    
    switch (enTouchState44)
    {
        case TOUCH_IDLE: // Start with 44
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x10C) == 0x000) && ((u32aCubeTouch[4] & 0x1C0) == 0x100) && ((u32aCubeTouch[3] & 0x000) == 0x000) && ((u32aCubeTouch[2] & 0x10C) == 0x000) && ((u32aCubeTouch[1] & 0x007) == 0x000) && ((u32aCubeTouch[0] & 0x1FF) == 0x000)) // Start with 44
                    || ( ((u32aCubeTouch[5] & 0x000) == 0x000) && ((u32aCubeTouch[4] & 0x10C) == 0x100) && ((u32aCubeTouch[3] & 0x007) == 0x000) && ((u32aCubeTouch[2] & 0x1FF) == 0x000) && ((u32aCubeTouch[1] & 0x10C) == 0x000) && ((u32aCubeTouch[0] & 0x007) == 0x000)) // Start with 44
                )
            {
                u32Timer25ms_Delay44 = TOUCHTIME;
                enTouchState44 = TOUCH_100;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r44 (1st)"); 
                #endif
            }
            break;

        case TOUCH_100: // Waiting for 2nd touch -> 39 or 43
        
            if ( (0 == (u32aCubeTouch[4] & TOUCH8)) && (u32aCubeTouch[4] & TOUCH3) )
            {
                enTouchState44 = TOUCH_100_008; 
                u32Timer25ms_Delay44 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r39 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[4] & TOUCH8)) && (u32aCubeTouch[4] & TOUCH7) )
            {
                enTouchState44 = TOUCH_100_080; 
                u32Timer25ms_Delay44 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r43 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_100_008: // Waiting for 3rd touch -> 38

            if (u32aCubeTouch[4] & TOUCH2)
            {
                enTouchState44 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_01_00; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r38 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_100_080: // Waiting for 3rd touch -> 42

            if (u32aCubeTouch[4] & TOUCH6)
            {
                enTouchState44 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_10_11; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r42 (3rd)"); 
                #endif
            }
            break;
        
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState44 [%d] ***", enTouchState44);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState44)
    #endif
    
    #ifdef P5
    // ------
    // PAGE 5
    // ------
    
    // Touch 45
    
    switch (enTouchState45)
    {
        case TOUCH_IDLE: // Start with 45
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x007) == 0x001) && ((u32aCubeTouch[4] & 0x1FF) == 0x000) && ((u32aCubeTouch[3] & 0x10C) == 0x000) && ((u32aCubeTouch[2] & 0x1C0) == 0x000) && ((u32aCubeTouch[1] & 0x000) == 0x000) && ((u32aCubeTouch[0] & 0x061) == 0x000)) // Start with 45
                    || ( ((u32aCubeTouch[5] & 0x061) == 0x001) && ((u32aCubeTouch[4] & 0x007) == 0x000) && ((u32aCubeTouch[3] & 0x1FF) == 0x000) && ((u32aCubeTouch[2] & 0x061) == 0x000) && ((u32aCubeTouch[1] & 0x1C0) == 0x000) && ((u32aCubeTouch[0] & 0x000) == 0x000)) // Start with 45
                )
            {
                u32Timer25ms_Delay45 = TOUCHTIME;
                enTouchState45 = TOUCH_001;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r45 (1st)"); 
                #endif
            }
            break;

        case TOUCH_001: // Waiting for 2nd touch -> 46 or 50
        
            if ( (0 == (u32aCubeTouch[5] & TOUCH0)) && (u32aCubeTouch[5] & TOUCH1) )
            {
                enTouchState45 = TOUCH_001_002; 
                u32Timer25ms_Delay45 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r46 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[5] & TOUCH0)) && (u32aCubeTouch[5] & TOUCH5) )
            {
                enTouchState45 = TOUCH_001_020; 
                u32Timer25ms_Delay45 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r50 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_001_002: // Waiting for 3rd touch -> 47

            if (u32aCubeTouch[5] & TOUCH2)
            {
                enTouchState45 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_05_00; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r47 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_001_020: // Waiting for 3rd touch -> 51

            if (u32aCubeTouch[5] & TOUCH6)
            {
                enTouchState45 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_16_17; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r51 (3rd)"); 
                #endif
            }
            break;
             
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState45 [%d] ***", enTouchState45);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState45)
  
    // Touch 46
    
    switch (enTouchState46)
    {
        case TOUCH_IDLE: // Start with 46
        
            if (    
                    ( ((u32aCubeTouch[5] & 0x092) == 0x002) && ((u32aCubeTouch[4] & 0x038) == 0x000) && ((u32aCubeTouch[3] & 0x000) == 0x000) && ((u32aCubeTouch[2] & 0x092) == 0x000) && ((u32aCubeTouch[1] & 0x038) == 0x000) && ((u32aCubeTouch[0] & 0x000) == 0x000)) // Start with 46
                )
            {
                u32Timer25ms_Delay46 = TOUCHTIME;
                enTouchState46 = TOUCH_002;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r46 (1st)"); 
                #endif
            }
            break;

        case TOUCH_002: // Waiting for 2nd touch -> 49

            if ( (0 == (u32aCubeTouch[5] & TOUCH1)) && (u32aCubeTouch[5] & TOUCH4) )
            {
                enTouchState46 = TOUCH_002_010; 
                u32Timer25ms_Delay46 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r49 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_002_010: // Waiting for 3rd touch -> 52

            if (u32aCubeTouch[5] & TOUCH7)
            {
                enTouchState46 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_13_12; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r52 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState46 [%d] ***", enTouchState46);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState46)

    // Touch 47
    
    switch (enTouchState47)
    {
        case TOUCH_IDLE: // Start with 47
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x10C) == 0x004) && ((u32aCubeTouch[4] & 0x1C0) == 0x000) && ((u32aCubeTouch[3] & 0x000) == 0x000) && ((u32aCubeTouch[2] & 0x10C) == 0x000) && ((u32aCubeTouch[1] & 0x007) == 0x000) && ((u32aCubeTouch[0] & 0x1FF) == 0x000)) // Start with 47
                    || ( ((u32aCubeTouch[5] & 0x007) == 0x004) && ((u32aCubeTouch[4] & 0x1FF) == 0x000) && ((u32aCubeTouch[3] & 0x10C) == 0x000) && ((u32aCubeTouch[2] & 0x1C0) == 0x000) && ((u32aCubeTouch[1] & 0x000) == 0x000) && ((u32aCubeTouch[0] & 0x061) == 0x000)) // Start with 47
                )
            {
                u32Timer25ms_Delay47 = TOUCHTIME;
                enTouchState47 = TOUCH_004;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r47 (1st)"); 
                #endif
            }
            break;

        case TOUCH_004: // Waiting for 2nd touch -> 46 or 48
        
            if ( (0 == (u32aCubeTouch[5] & TOUCH2)) && (u32aCubeTouch[5] & TOUCH1) )
            {
                enTouchState47 = TOUCH_004_002; 
                u32Timer25ms_Delay47 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r46 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[5] & TOUCH2)) && (u32aCubeTouch[5] & TOUCH3) )
            {
                enTouchState47 = TOUCH_004_008; 
                u32Timer25ms_Delay47 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r48 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_004_002: // Waiting for 3rd touch -> 45

            if (u32aCubeTouch[5] & TOUCH0)
            {
                enTouchState47 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_00_05; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r45 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_004_008: // Waiting for 3rd touch -> 53

            if (u32aCubeTouch[5] & TOUCH8)
            {
                enTouchState47 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_10_11; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r53 (3rd)"); 
                #endif
            }
            break;
        
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState47 [%d] ***", enTouchState47);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState47)
     
    
    // Touch 48
    
    switch (enTouchState48)
    {
        case TOUCH_IDLE: // Start with 48
        
            if (    
                    ( ((u32aCubeTouch[5] & 0x038) == 0x008) && ((u32aCubeTouch[4] & 0x000) == 0x000) && ((u32aCubeTouch[3] & 0x092) == 0x000) && ((u32aCubeTouch[2] & 0x038) == 0x000) && ((u32aCubeTouch[1] & 0x000) == 0x000) && ((u32aCubeTouch[0] & 0x092) == 0x000)) // Start with 48
            )
            {
                u32Timer25ms_Delay48 = TOUCHTIME;
                enTouchState48 = TOUCH_008;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r48 (1st)"); 
                #endif
            }
            break;

        case TOUCH_008: // Waiting for 2nd touch -> 49

            if ( (0 == (u32aCubeTouch[5] & TOUCH3)) && (u32aCubeTouch[5] & TOUCH4) )
            {
                enTouchState48 = TOUCH_008_010; 
                u32Timer25ms_Delay48 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r49 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_008_010: // Waiting for 3rd touch -> 50

            if (u32aCubeTouch[5] & TOUCH5)
            {
                enTouchState48 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_01_04; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r50 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState48 [%d] ***", enTouchState48);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState48)
    
    // Touch 50
    
    switch (enTouchState50)
    {
        case TOUCH_IDLE: // Start with 50
        
            if (    
                    ( ((u32aCubeTouch[5] & 0x038) == 0x020) && ((u32aCubeTouch[4] & 0x000) == 0x000) && ((u32aCubeTouch[3] & 0x092) == 0x000) && ((u32aCubeTouch[2] & 0x038) == 0x000) && ((u32aCubeTouch[1] & 0x000) == 0x000) && ((u32aCubeTouch[0] & 0x092) == 0x000)) // Start with 50
                )
            {
                u32Timer25ms_Delay50 = TOUCHTIME;
                enTouchState50 = TOUCH_020;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r50 (1st)"); 
                #endif
            }
            break;

        case TOUCH_020: // Waiting for 2nd touch -> 49

            if ( (0 == (u32aCubeTouch[5] & TOUCH5)) && (u32aCubeTouch[5] & TOUCH4) )
            {
                enTouchState50 = TOUCH_020_010; 
                u32Timer25ms_Delay50 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r49 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_020_010: // Waiting for 3rd touch -> 48

            if (u32aCubeTouch[5] & TOUCH3)
            {
                enTouchState50 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_04_01; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r48 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState50 [%d] ***", enTouchState50);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState50)
    
    // Touch 51
    
    switch (enTouchState51)
    {
        case TOUCH_IDLE: // Start with 51
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x1C0) == 0x040) && ((u32aCubeTouch[4] & 0x000) == 0x000) && ((u32aCubeTouch[3] & 0x061) == 0x000) && ((u32aCubeTouch[2] & 0x007) == 0x000) && ((u32aCubeTouch[1] & 0x1FF) == 0x000) && ((u32aCubeTouch[0] & 0x10C) == 0x000)) // Start with 51
                    || ( ((u32aCubeTouch[5] & 0x061) == 0x040) && ((u32aCubeTouch[4] & 0x007) == 0x000) && ((u32aCubeTouch[3] & 0x1FF) == 0x000) && ((u32aCubeTouch[2] & 0x061) == 0x000) && ((u32aCubeTouch[1] & 0x1C0) == 0x000) && ((u32aCubeTouch[0] & 0x000) == 0x000)) // Start with 51
                )
            {
                u32Timer25ms_Delay51 = TOUCHTIME;
                enTouchState51 = TOUCH_040;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r51 (1st)"); 
                #endif
            }
            break;

        case TOUCH_040: // Waiting for 2nd touch -> 50 or 52
        
            if ( (0 == (u32aCubeTouch[5] & TOUCH6)) && (u32aCubeTouch[5] & TOUCH5) )
            {
                enTouchState51 = TOUCH_040_020; 
                u32Timer25ms_Delay51 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r50 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[5] & TOUCH6)) && (u32aCubeTouch[5] & TOUCH7) )
            {
                enTouchState51 = TOUCH_040_080; 
                u32Timer25ms_Delay51 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r52 (2nd)"); 
                #endif
            }
            break;
       
        case TOUCH_040_020: // Waiting for 3rd touch -> 45

            if (u32aCubeTouch[5] & TOUCH0)
            {
                enTouchState51 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_17_16; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r45 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_040_080: // Waiting for 3rd touch -> 53

            if (u32aCubeTouch[5] & TOUCH8)
            {
                enTouchState51 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_03_02; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r53 (3rd)"); 
                #endif
            }
            break;
             
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState51 [%d] ***", enTouchState51);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState51)
  
    // Touch 52
    
    switch (enTouchState52)
    {
        case TOUCH_IDLE: // Start with 52
        
            if (    
                    ( ((u32aCubeTouch[5] & 0x092) == 0x080) && ((u32aCubeTouch[4] & 0x038) == 0x000) && ((u32aCubeTouch[3] & 0x000) == 0x000) && ((u32aCubeTouch[2] & 0x092) == 0x000) && ((u32aCubeTouch[1] & 0x038) == 0x000) && ((u32aCubeTouch[0] & 0x000) == 0x000)) // Start with 52
                )
            {
                u32Timer25ms_Delay52 = TOUCHTIME;
                enTouchState52 = TOUCH_080;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r52 (1st)"); 
                #endif
            }
            break;

        case TOUCH_080: // Waiting for 2nd touch -> 49

            if ( (0 == (u32aCubeTouch[5] & TOUCH7)) && (u32aCubeTouch[5] & TOUCH4) )
            {
                enTouchState52 = TOUCH_080_010; 
                u32Timer25ms_Delay52 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r49 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_080_010: // Waiting for 3rd touch -> 46

            if (u32aCubeTouch[5] & TOUCH1)
            {
                enTouchState52 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_12_13; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r46 (3rd)"); 
                #endif
            }
            break;
         
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState52 [%d] ***", enTouchState52);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState52)

    // Touch 53
    
    switch (enTouchState53)
    {
        case TOUCH_IDLE: // Start with 53
        
            if (    
                       ( ((u32aCubeTouch[5] & 0x1C0) == 0x100) && ((u32aCubeTouch[4] & 0x000) == 0x000) && ((u32aCubeTouch[3] & 0x061) == 0x000) && ((u32aCubeTouch[2] & 0x007) == 0x000) && ((u32aCubeTouch[1] & 0x1FF) == 0x000) && ((u32aCubeTouch[0] & 0x10C) == 0x000)) // Start with 53
                    || ( ((u32aCubeTouch[5] & 0x10C) == 0x100) && ((u32aCubeTouch[4] & 0x1C0) == 0x000) && ((u32aCubeTouch[3] & 0x000) == 0x000) && ((u32aCubeTouch[2] & 0x10C) == 0x000) && ((u32aCubeTouch[1] & 0x007) == 0x000) && ((u32aCubeTouch[0] & 0x1FF) == 0x000)) // Start with 53
                )
            {
                u32Timer25ms_Delay53 = TOUCHTIME;
                enTouchState53 = TOUCH_100;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r53 (1st)"); 
                #endif
            }
            break;

        case TOUCH_100: // Waiting for 2nd touch -> 48 or 52
        
            if ( (0 == (u32aCubeTouch[5] & TOUCH8)) && (u32aCubeTouch[5] & TOUCH3) )
            {
                enTouchState53 = TOUCH_100_008; 
                u32Timer25ms_Delay53 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r48 (2nd)"); 
                #endif
            }

            if ( (0 == (u32aCubeTouch[5] & TOUCH8)) && (u32aCubeTouch[5] & TOUCH7) )
            {
                enTouchState53 = TOUCH_100_080; 
                u32Timer25ms_Delay53 = TOUCHTIME; 
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r52 (2nd)"); 
                #endif
            }
            break;
        
        case TOUCH_100_008: // Waiting for 3rd touch -> 47

            if (u32aCubeTouch[5] & TOUCH2)
            {
                enTouchState53 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_11_10; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r47 (3rd)"); 
                #endif
            }
            break;

        case TOUCH_100_080: // Waiting for 3rd touch -> 51

            if (u32aCubeTouch[5] & TOUCH6)
            {
                enTouchState53 = TOUCH_IDLE; 
                enCubeMove = CUBEMOVE_02_03; 
                u32CubeMoveSteps = 3;
                #ifndef SoftwareUART__DISABLED 
                    UART_PutString("\r51 (3rd)"); 
                #endif
            }
            break;
        
        default:
            #ifndef SoftwareUART__DISABLED 
                sprintf(aPrintfBuffer, "\r*** Undefined enTouchState53 [%d] ***", enTouchState53);
                UART_PutString(aPrintfBuffer);
            #endif
            break;
    } // switch (enTouchState53)

    #endif
      
    } //if (0 == u32CubeMoveSteps)

    //
    // Action depending on mode
    //
    
    switch (enCubeMode)
    {
        case CUBEMODE_MIX:
        
            StripLights_MemClear(0x00000000);
            StripLights_Pixel(0, 0x00000055); // - - b b g g r r
            StripLights_Pixel(1, 0x00005500); // - - b b g g r r
            StripLights_Pixel(2, 0x00550000); // - - b b g g r r
            StripLights_Pixel(3, 0x0000AA00); // - - b b g g r r
            StripLights_Pixel(4, 0x000000AA); // - - b b g g r r
            StripLights_Pixel(5, 0x00AA0000); // - - b b g g r r
            StripLights_Pixel(6, 0x0000FF00); // - - b b g g r r
            StripLights_Pixel(7, 0x00FF0000); // - - b b g g r r
            StripLights_Pixel(8, 0x000000FF); // - - b b g g r r
            //HOWE TRIG StripLights_Trigger();
            enCubeMode = CUBEMODE_MIX_WAIT_FOR_TOUCH;
            break;
            
        case CUBEMODE_MIX_WAIT_FOR_TOUCH:
           
            if (u32aCubeTouch[0])
            {
                if (u32aCubeTouch[0] & 0x100)
                {
                    u32temp = 30;   
                }
                else
                if (u32aCubeTouch[0] & 0x080)
                {
                    u32temp = 20;   
                }
                else                
                if (u32aCubeTouch[0] & 0x040)
                {
                    u32temp = 14;  
                }
                else                
                if (u32aCubeTouch[0] & 0x020)
                {
                    u32temp = 12;   
                }
                else                
                if (u32aCubeTouch[0] & 0x010)
                {
                    u32temp = 10;   
                }
                else                
                if (u32aCubeTouch[0] & 0x008)
                {
                    u32temp = 6;    
                }
                else                
                if (u32aCubeTouch[0] & 0x004)
                {
                    u32temp = 4;   
                }
                else                
                if (u32aCubeTouch[0] & 0x002)
                {
                    u32temp = 3;   
                }
                else
                {
                    u32temp = 2;    
                }
                
                CubeLED_Init();
                CubeLED_Refresh();
                enCubeMode = CUBEMODE_MIX_DONE;
            }
            break;
            
        case CUBEMODE_MIX_DONE:
            
                if (u32temp == 0)
                {
                    enCubeMode = CUBEMODE_RUN;   
                }
                else
                {
                    if (u32CubeMoveSteps == 0)
                    {
                        enCubeMove = TimerRandom_ReadCounter()%18; // Pseudo random movement (0..17)
                        u32CubeMoveSteps = 3;
                        u32temp = u32temp - 1;
                    }
                }
                break;
            
                
        case CUBEMODE_LIGHT:
        
            StripLights_MemClear(0x00000000);
            u32LedIntensity_temp = u32LedIntensity;
            u32LedIntensity = 0;
            StripLights_Pixel(0, YELLOW); // - - b b g g r r
            u32LedIntensity = 8;
            StripLights_Pixel(1, YELLOW); // - - b b g g r r
            u32LedIntensity = 7;
            StripLights_Pixel(2, YELLOW); // - - b b g g r r
            u32LedIntensity = 6;
            StripLights_Pixel(3, YELLOW); // - - b b g g r r
            u32LedIntensity = 5;
            StripLights_Pixel(4, YELLOW); // - - b b g g r r
            u32LedIntensity = 4;
            StripLights_Pixel(5, YELLOW); // - - b b g g r r
            u32LedIntensity = 3;
            StripLights_Pixel(6, YELLOW); // - - b b g g r r
            u32LedIntensity = 2;
            StripLights_Pixel(7, YELLOW); // - - b b g g r r
            u32LedIntensity = 1;
            StripLights_Pixel(8, YELLOW); // - - b b g g r r
            //HOWE TRIG StripLights_Trigger();
            enCubeMode = CUBEMODE_LIGHT_WAIT_FOR_TOUCH;
            break;
            
        case CUBEMODE_LIGHT_WAIT_FOR_TOUCH:
           
            if (u32aCubeTouch[0])
            {
                if (u32aCubeTouch[0] & 0x100)
                {
                    u32LedIntensity = 1;   
                }
                else
                if (u32aCubeTouch[0] & 0x080)
                {
                    u32LedIntensity = 2;   
                }
                else                
                if (u32aCubeTouch[0] & 0x040)
                {
                    u32LedIntensity = 3;  
                }
                else                
                if (u32aCubeTouch[0] & 0x020)
                {
                    u32LedIntensity = 4;   
                }
                else                
                if (u32aCubeTouch[0] & 0x010)
                {
                    u32LedIntensity = 5;   
                }
                else                
                if (u32aCubeTouch[0] & 0x008)
                {
                    u32LedIntensity = 6;    
                }
                else                
                if (u32aCubeTouch[0] & 0x004)
                {
                    u32LedIntensity = 7;   
                }
                else                
                if (u32aCubeTouch[0] & 0x002)
                {
                    u32LedIntensity = 8;   
                }
                else
                {
                    u32CubeOffFlag = 1;                      // initital to switch off the cube
                    u32LedIntensity = u32LedIntensity_temp;  // keep intensity when switched on later
                }
                
                enCubeMode = CUBEMODE_LIGHT_DONE;
            }
            break;
         
        case CUBEMODE_LIGHT_DONE:
            
            if (u32aCubeTouch[0]==0)
            {
                if (u32CubeOffFlag == 1)
                {
                    u32LedIntensity_temp = u32LedIntensity;
                    u32LedIntensity = 5;
                    StripLights_MemClear(RED);
                    StripLights_Trigger();
                    CyDelay(200);
                    PwrOn_Write(CUBE_OFF);
                    while(1);   
                }
                else
                {
                    switch (enCubeModeKeep)
                    {
                        case CUBEMODE_MIX_WAIT_FOR_TOUCH:
                            enCubeMode = CUBEMODE_MIX;
                            break;
                        
                        default:
                            CubeLED_Refresh();
                            enCubeMode = CUBEMODE_RUN;
                    }//switch  
                }
                
                
            }   
          
        case CUBEMODE_RUN: break;
                    
        default:
            
            enCubeMode = CUBEMODE_RUN;
            break;
        
    } // switch (enCubeMode)
    
    //
    // Movement
    //
    
    if ( u32CubeMoveSteps && (u32Timer25ms_DelayTurn == 0) )
    {
        switch (enCubeMove)
        {
            case CUBEMOVE_01_00: CubeMove_01_to_00(); break;
            case CUBEMOVE_00_01: CubeMove_00_to_01(); break;
            case CUBEMOVE_04_05: CubeMove_04_to_05(); break;
            case CUBEMOVE_05_04: CubeMove_05_to_04(); break;
            case CUBEMOVE_07_06: CubeMove_07_to_06(); break;
            case CUBEMOVE_06_07: CubeMove_06_to_07(); break;
            case CUBEMOVE_05_00: CubeMove_05_to_00(); break;
            case CUBEMOVE_00_05: CubeMove_00_to_05(); break;
            case CUBEMOVE_04_01: CubeMove_04_to_01(); break;
            case CUBEMOVE_01_04: CubeMove_01_to_04(); break;
            case CUBEMOVE_03_02: CubeMove_03_to_02(); break;
            case CUBEMOVE_02_03: CubeMove_02_to_03(); break;
            case CUBEMOVE_10_11: CubeMove_10_to_11(); break;
            case CUBEMOVE_11_10: CubeMove_11_to_10(); break;
            case CUBEMOVE_13_12: CubeMove_13_to_12(); break;
            case CUBEMOVE_12_13: CubeMove_12_to_13(); break;
            case CUBEMOVE_16_17: CubeMove_16_to_17(); break;
            case CUBEMOVE_17_16: CubeMove_17_to_16(); break;
        } // switch (enCubeMove)
        
        u32CubeMoveSteps = u32CubeMoveSteps - 1;
        u32Timer25ms_DelayTurn = ROTATETIME;
        
        if (0 == u32CubeMoveSteps)
        {
            if (CheckCubeSolved())
            {
                u32LedIntensity_temp = u32LedIntensity;
                u32LedIntensity = 8;
                CubeLED_Refresh();
                StripLights_Trigger();
                CyDelay(500);                    
                u32LedIntensity = 1;
                CubeLED_Refresh();
                StripLights_Trigger();
                CyDelay(500);
                u32LedIntensity = 8;
                CubeLED_Refresh();
                StripLights_Trigger();
                CyDelay(500);                    
                u32LedIntensity = 1;
                CubeLED_Refresh();
                StripLights_Trigger();
                CyDelay(500);
                u32LedIntensity = 8;
                CubeLED_Refresh();
                StripLights_Trigger();
                CyDelay(500);                    
                u32LedIntensity = 1;
                CubeLED_Refresh();
                StripLights_Trigger();
                CyDelay(500);
                u32LedIntensity = u32LedIntensity_temp;
                CubeLED_Refresh();
            }
        }

    } // if (u32CubeMoveSteps && (u32Timer25ms_DelayTurn == 0) )
   
}


int main(void)
{
    u32LedIntensity = 3;
    
    TimerRandom_Start(); // Used for the Random Number Generation
    
    CyGlobalIntEnable; /* Enable global interrupts. */

    /* Place your initialization/startup code here (e.g. MyInst_Start()) */

    // UARTDEBUG
    
    #ifndef SoftwareUART__DISABLED    
        UART_Start();
        UART_PutString("\rCyCube v3");
    #endif
     
    // I2C
    
    #ifdef CY_SCB_EZI2C_H
        EZI2C_Start();
        EZI2C_EzI2CSetBuffer1(sizeof(CapSense_dsRam), sizeof(CapSense_dsRam), (uint8 *)&CapSense_dsRam);
    #endif
    
    #ifdef CY_SCB_I2C_H
        I2C_Start();
    #endif

    // SCB / SPI / StripLights

    StripLights_Start();
    
    StripLights_MemClear(0x0000000);
    StripLights_Trigger();
    
    // Intro
    for (u32LedIntensity = 10; u32LedIntensity > 0; u32LedIntensity --)
    {
        CubeLED_Init();
        CubeLED_Refresh();
        StripLights_Trigger();
        CyDelay(100);
    }
    CyDelay(500);
    
    while (u32LedIntensity < LED_INTENSITY)
    {
        u32LedIntensity = u32LedIntensity + 1;
        CubeLED_Init();
        CubeLED_Refresh();
        StripLights_Trigger();
        CyDelay(100); 
    }
  
    // CapSense
    
    CapSense_Start();           // Initialize Component
    CapSense_ScanAllWidgets();  // Scan all widgets
    
    // Sytick
    
    CyIntSetSysVector((SysTick_IRQn + 16), mySystick_ISR); // Map systick ISR to the user defined ISR. SysTick_IRQn is already defined in core_cm0.h file
    SysTick_Config(SYSTICKS); // e.g.: 12000, Enable Systick timer with desired period/number of ticks
  
    // Timer25ms / 40Hz
    
    Timer25ms_Start();
    irq_Timer25ms_StartEx(isr_Timer25ms);
    
    u32Timer25ms_Delay = 20;
    
    enCubeMode = CUBEMODE_MIX;
    
    
//    enCubeMode = CUBEMODE_RUN;
//    CyDelay (333);
//    for (u8i = 0; u8i<3; u8i++)
//    {
//        enCubeMove = TimerRandom_ReadCounter()%18; // Pseudo random movement (0..17)
//        u32CubeMoveSteps = 3;
//        u32Timer25ms_Delay = 0;       
//        CyDelay(33);
//        while(u32CubeMoveSteps);
//    }
    
//    enCubeMode = CUBEMODE_RUN;
//    enCubeMove = CUBEMOVE_00_05; u32CubeMoveSteps = 6; // 2x
//    while (u32CubeMoveSteps);
//    enCubeMove = CUBEMOVE_16_17; u32CubeMoveSteps = 3; 
//    while (u32CubeMoveSteps);
//    enCubeMove = CUBEMOVE_01_00; u32CubeMoveSteps = 6; // 2x
//    while (u32CubeMoveSteps);
//    enCubeMove = CUBEMOVE_11_10; u32CubeMoveSteps = 3; 
//    while (u32CubeMoveSteps);
//    enCubeMove = CUBEMOVE_01_00; u32CubeMoveSteps = 6; // 2x
//    while (u32CubeMoveSteps);
//    enCubeMove = CUBEMOVE_00_05; u32CubeMoveSteps = 6; // 2x 
//    while (u32CubeMoveSteps);
//    enCubeMove = CUBEMOVE_06_07; u32CubeMoveSteps = 6; // 2x 
//    while (u32CubeMoveSteps);
//    enCubeMove = CUBEMOVE_10_11; u32CubeMoveSteps = 3; 
//    while (u32CubeMoveSteps);
//    enCubeMove = CUBEMOVE_00_05; u32CubeMoveSteps = 6; // 2x
//    while (u32CubeMoveSteps);
//    enCubeMove = CUBEMOVE_11_10; u32CubeMoveSteps = 6; // 2x 
//    while (u32CubeMoveSteps);
//    enCubeMove = CUBEMOVE_00_05; u32CubeMoveSteps = 3; 
//    while (u32CubeMoveSteps);
//    enCubeMove = CUBEMOVE_03_02; u32CubeMoveSteps = 6; // 2x 
//    while (u32CubeMoveSteps);
//    enCubeMove = CUBEMOVE_11_10; u32CubeMoveSteps = 6; // 2x 
//    while (u32CubeMoveSteps);
//    enCubeMove = CUBEMOVE_05_00; u32CubeMoveSteps = 3; 
//    while (u32CubeMoveSteps);
//    enCubeMove = CUBEMOVE_00_01; u32CubeMoveSteps = 3; 
//    while (u32CubeMoveSteps);
//    enCubeMove = CUBEMOVE_00_05; u32CubeMoveSteps = 3; 
//    while (u32CubeMoveSteps);
//    enCubeMove = CUBEMOVE_11_10; u32CubeMoveSteps = 3; 
//    while (u32CubeMoveSteps);
//    enCubeMove = CUBEMOVE_06_07; u32CubeMoveSteps = 6; // 2x  
//    while (u32CubeMoveSteps);
//    enCubeMove = CUBEMOVE_16_17; u32CubeMoveSteps = 3; 
//    while (u32CubeMoveSteps);
//    enCubeMove = CUBEMOVE_07_06; u32CubeMoveSteps = 3; 
//    while (u32CubeMoveSteps);
   
    for(;;)
    {
        
       // see CY_ISR(isr_Timer25ms)
        
    } // for(;;)
}

/* [] END OF FILE */

